/********************************************************************

  THIS CREATES OUR BASE DATASET FOR THE MAGNET SCHOOL ANALYSIS 
 	
   PART I     Merges application files with other data files
              and creates basic demographic and enrollment variables
              (saves magbase2000.dta and magbase2001.dta)
	
   PART II    Combines 2000 and 2001 files and creates imputed grade variable
              (saves magbase.dta)

   PART III   Eliminates duplicate/bad obs and creates school type variables
              (saves magbasevalid.dta)

 ********************************************************************/
 
 
drop _all
program drop _all
macro drop _all
set more off
set mem 300m
#delimit;


** set up global indicating which machine running program on; 

global n=0;


 		****************;
 		*** PART I ***;
 		****************;

** uncompressing files;

if ${n}==0{;
!gzip -d CASE_EXAMS\case*s.dta.gz;
!gzip -d CEN_RELN\rel_trcts.dta.gz;
!gzip -d CENSUS\allpub.dta.gz;
!gzip -d CENSUS\blcrim94.dta.gz;
!gzip -d CENSUS\cens00tr.dta.gz;
!gzip -d GEOCODE\ap_geo.dta.gz;
!gzip -d GEOCODE\pub_geo.dta.gz;
!gzip -d GEOCODE\tracttotractdistances.dta.gz; 
!gzip -d GEOCODE\IL_final_add.dta.gz;
!gzip -d GEOCODE\IN_final_add.dta.gz;
!gzip -d GEOCODE\census_*.dta.gz;
!gzip -d PRIV\all_priv.dta.gz;
!gzip -d allschbud.dta.gz;
!gzip -d allm*.dta.gz;
!gzip -d cpsmaglnk.dta.gz;
!gzip -d grspr*.dta.gz;
!gzip -d itbs*.dta.gz;
!gzip -d leavelog0304.dta.gz;
!gzip -d magnet*.dta.gz;
!gzip -d sc*.dta.gz;
!gzip -d tap*.dta.gz;
!gzip -d tchrs99.dta.gz;
};


program define doit;
capture log close;
log using magbase`1'.log, replace;


********************;
*** Merge Files  ***;
********************;

/*** MAGNET SCHOOL APPLICATION FILE ***/

* Source: CPS Board, 1 record per application;
* includes both students who had been enrolled in CPS and are applying for
  a choice program in the following year, and students not in the CPS who
  are applying to be in the CPS for the following year (mostly pre-K and K).
  Those already in the CPS should have a CPS ID in the applications data;

if ${n}==1{; global src="c:\projects\Magnet Schools\data\"; };
 use "${src}magnet`1'";

/*** MATCHED CPS IDS FROM CHAPIN HALL MATCH ***/

mmerge year individ using "${src}cpsmaglnk.dta", t(1:1) unmatched(master)
 ukeep(idseq stuid);

   label var individ "unique application identifier";
  disp "** total number of applications **";
  count;
  disp "** number of students applying **";
  sort idseq;
   label var idseq "unique student ID that links applications";
  count if idseq~=idseq[_n-1];
  disp "** number of applications per student **";
  count if cunit==.;
  egen napp=count(cunit), by(idseq);
  sort idseq;
  summ napp if idseq~=idseq[_n-1];
  drop napp;
  disp "** fraction of applications by grade **";
  * first make grade consistent across 2000 and 2001;
  for num 1/9: replace gr="0X" if gr=="X";
  tab gr, miss;

** compare the student ids in the original application file (sid) with the 
  ids derived from the Chapin Hall match (stuid); 

  disp "** fix mis-entry for variable sid **";
  summ sid stuid;
  tab sid if sid<9999999;
  replace sid=. if sid<9999999;

  disp "** In which grades are students missing CPS IDs? **";
  gen nosid=(sid==.);
  tabstat nosid, by(gr);
  drop nosid;

  disp "** does stuid always match within the same idseq? **";
  egen long temp1=max(stuid), by(idseq);
  gen temp2=(stuid==temp1);
  summ temp2;
  drop temp*;

  disp "** When are reported and matched SIDs missing? **";
  gen dsid=sid!=.;
  gen dstuid=stuid!=.;
  tab dsid dstuid, row col; 

** Note: in 2000, 3,483 of 18,494 obs that have no ID from the Chapin match 
   do have an ID from the original magnet school file. This is because Chapin 
   Hall matched based solely on name, birthdate, address, race and gender. 
   We can infer, though, that we capture 95.66% of observations that should 
   have been matched by the matching algorithm;

** Note: in 2000, for the 16% of obs (15,011) that do not have a matching 
   CPS ID, we do not know for certain whether the students did not attend the 
   CPS in the Fall or we simply cannot properly match them.  Since 19,103 
   without an ID reported on the application were matched, we infer that we 
   should have matched 19,103/.9566, or 19,970.  This means that we missed
   867 cases, and that 5.8% (867/15,011) of observations with no reported
   CPS ID and not assigned an ID by the matching algorithm should have been
   assigned one;

  disp "** How do reported SIDs and Chapin SIDs match up? **"; 
  gen descrep=stuid!=sid&sid!=.&stuid!=.;
  tab descrep;
  drop dsid dstuid descrep;
 
** !!Note: We are now using the reported ID whenever available, and the
   Chapin Hall ID if that is missing.  We should do the reverse if we do not 
   restrict our main analysis to students already enrolled at the time they 
   apply to make sure we don't end up with selection biases;

  gen tempsame=(sid==stuid & sid~=. & stuid~=.);
  disp "** use Chapin ID if reported ID missing **";
  replace sid=stuid if sid==.;

** Propogate "sid" through observations with the same idseq;

  disp "**Check: how many obs have multiple sid per idseq **";
  egen temp=nvals(sid), by(idseq);
  * note: nvals sets result to missing for obs with missing sid;
  tab temp, miss;
  replace temp=(temp>1&temp~=.);
  egen byte badmtch1=max(temp), by(idseq);
   label var badmtch1 "bad ID match: multiple sid's";
  drop temp;
  disp "** fill in student ID across matched records **";
  egen long temp1=mode(sid), by(idseq);
  * Note: if more than 1 mode, use one that matches Chapin Hall report;
  gen long temp2=sid if tempsame==1;
  egen long temp3=mode(temp2), by(idseq);
  egen long temp4=max(temp2), by(idseq);
  replace temp1=temp3 if temp1==.;
  replace temp1=temp4 if temp1==.;
  * Note: if still missing, we arbitraily choose the maximum ID; 
  egen long temp5=max(sid), by(idseq);
  replace temp1=temp5 if temp1==.;
  disp "**replace missing sid's w/values from obs with identical idseq**";
  replace sid=temp1 if sid==.;
  disp "**how many obs have multiple non-missing sid's within idseq **";
  count if temp1~=sid & sid~=.;
  tab badmtch1 if temp1~=sid & sid~=.;
  replace sid=temp1 if sid~=temp1;
  drop temp*;

  disp "** fix problem cases where student is split across 2 idseq's **";
  if `1'==2000{;
   gen temp=1 if idseq=="00003616"|idseq=="00001743";
   list idseq stud stuid sid if temp==1;
   list bdate sx rc aaunit if temp==1;
   replace idseq="00001743" if temp==1;
   drop temp;
  };

  if `1'==2001{;
   for num 20184833 33665113 35637052 35772006:
    egen temp=max(sid==X), by(idseq) \
    list idseq stud stuid sid if temp==1 \
    list bdate sx rc aaunit if temp==1 \ drop temp;
   replace idseq="00028607" if idseq=="00053270";
   replace idseq="00023621" if idseq=="00053958";
   replace idseq="00017302" if idseq=="00059282";
   replace idseq="00023623" if idseq=="00053163";
  };

** make sure if sid ever defined, always the same within idseq;
  egen long temp=mean(sid), by(idseq);
  disp "** should be no cases where sid is not constant across idseq **";
  count if sid~=temp;
  drop temp;

** drop unneeded variables;
  descr seq stud aads prmhdca address bphone hphone guardian upby;
  descr aads;
  tab aads;
  descr prmhdca;
  tab prmhdca, miss;
  tab prmhdca if gr=="08", miss;
  drop stuid seq stud aads prmhdca address bphone hphone guardian upby;

** convert year to numeric;
 gen temp=real(year);
 drop year;
 rename temp year;
 tab year;
  label var year "Spring year of application";

/***  Naming convention for variables below:
       S0 = Spring of base year (i.e., when student applied, 8th grade)
       F1 = Fall of first academic year after application (9th)
       S1 = Spring of first academic year after application (9th)  
       S2 = Spring of 2nd academic year after application (10th)
       S3 = Spring of 3rd academic year after application (11th)  
       S4 = Spring of 4th academic year after application (12th)  ***/

/*** GEOCODED APPLICATIONS DATA ***/

if ${n}==0{; global src="GEOCODE\"; };
if ${n}==1{; global src="c:\projects\magnet schools\geocode\"; };
 label drop __MERGE;
 mmerge year individ using "${src}ap_geo", t(1:1) unmatched(master) 
 ukeep(individ trct90s trct00s trct00 blgr90 blgr00 chgboth) 
 urename(trct90s tractS0_90 \ trct00s tractS0 \ trct00 tractS0_2 \
 blgr90 groupS0_90 \ blgr00 groupS0 \ chgboth badmtch2);
  label var tractS0 "student's tract at time of appl";
  label var groupS0 "student's blk grp at time of appl";
  label var badmtch2 "multiple addresses & phone #'s";
 disp "** how often do 1990 and 2000 tract #'s differ? **";
 count if tractS0~=tractS0_90;
 disp "** how often do 1990 and 2000 block group #'s differ? **";
 count if groupS0~=groupS0_90;
 * note: both tracts and block groups are very stable in Chicago;
 disp "** how often would 6-digit and 4-digit tracts differ? **";
 gen str6 temp=string(tractS0_2);
 replace temp=substr(temp,-2,.);
 tab temp;
 drop temp tractS0_90 groupS0_90 tractS0_2;

** check to see how well bad matches correlate with tails in numbers of apps;
 gen badmatch=max(badmtch1,badmtch2);
  label var badmatch "combined indicator of bad matches w/in idseq";
 descr badmtch* badmatch;
 egen temp1=count(cunit), by(idseq);
 egen temp2=tag(idseq);
 disp "** distribution of # of applications (1 obs/student) **";
 summ temp1 if temp2==1, detail;
 disp "** share w/ bad matches by obs and by student **";
 summ badmtch* badmatch;
 summ badmtch* badmatch if temp2==1;
 disp "** share w/bad matches among those with 15+ appl (by student) **";
 summ badmtch* badmatch if temp1>15 & temp2==1;
 drop temp*;

/*** MASTERFILE DATA FROM THE SEMESTER THE STUDENT APPLIED ***/

if ${n}==0{; global src="";
 if `1'==2001{; global full="full"; }; };
if ${n}==1{; global src="e:\data\masterfiles\"; };
 label drop __MERGE;
 mmerge sid using "${src}allm5`2'${full}", t(n:1) unmatched(master) 
 uif(statu5`2'==1|statu5`2'==2) ukeep(sid centract cenblock statu5`2' 
 granu5`2' ethni5`2' gend5`2' guard5`2' sped5`2' cursc5`2' bcat5`2' lunch5`2' 
 bdate5`2' aunit5`2') urename(centract tractS0_90 \ cenblock groupS0_90 \ 
 statu5`2' statuS0 \ granu5`2' gradeS0 \ ethni5`2' ethniS0 \ gend5`2' gendS0 \
 guard5`2' guardS0 \  sped5`2' spedS0 \ cursc5`2' curscS0 \ bcat5`2' bcatS0 \
 lunch5`2' lunchS0 \ bdate5`2' bdateS0 \ aunit5`2' aunitS0);

 * block group was not read in properly in masterfile data;
 list tractS0 groupS0 tractS0_90 groupS0_90 in 1/5;
 replace tractS0_90=tractS0_90-170310000;
 * convert 1990 tract numbers to 2000 numbers;
 if ${n}==0{; global src="CEN_RELN\"; };
 if ${n}==1{; global src="c:\projects\magnet schools\cen_reln\"; };
  label drop __MERGE;
  mmerge tractS0_90 using "${src}rel_trcts", t(n:1) unmatched(master)
  umatch(trct90s) ukeep(trct00s) urename(trct00s tractS0_mstr);
 disp "** were there any cases where 1990 tract had no match? **";
 count if tractS0_90~=. & tractS0_mstr==.;
 disp "** how often was the 1990 tract number actually changed? **";
 count if tractS0_90~=tractS0_mstr & tractS0_90~=. & tractS0_mstr~=.;
 * note: so few 4-digit tracts changed between 1990 and 2000 that from here
   on we do not bother adjusting;
 drop tractS0_90 groupS0_90;

 disp "** how often do master and application file tracts not match? **";
 gen temp=(tractS0_mstr~=tractS0) if tractS0~=. & tractS0_mstr~=.;
 summ temp;
 drop temp;

** get data on latitudes and longitudes to see how different these are;
 if ${n}==0{; global src="GEOCODE\"; };
 if ${n}==1{; global src="c:\projects\magnet schools\geocode\"; };
  gen county=17031;
 * match to tract in application file;
  * add extension to tracts with no .00 match in latitude/longitude data;
  gen double temp_tractS0=tractS0;
  for num 8080 8103 8105 8209 8228:
   replace temp_tractS0=temp_tractS0+.01 if temp_tractS0==X;
  replace temp_tractS0=8233.02 if temp_tractS0==8233;
  label drop __MERGE;
  mmerge county temp_tractS0 using "${src}census_tract_centroids_il", 
  t(n:1) unmatched(master) umatch(county tractid) uif(county==17031)
  ukeep(latitude longitude) urename(latitude latS0 \ longitude longS0);
   label var latS0 "home latitude at time of appl";
   label var longS0 "home longitude at time of appl";
 * match to tract in Master file;
  replace temp_tractS0=tractS0_mstr;
  for num 8080 8103 8105 8209 8228:
   replace temp_tractS0=temp_tractS0+.01 if temp_tractS0==X;
  replace temp_tractS0=8233.02 if temp_tractS0==8233;
  label drop __MERGE;
  mmerge county temp_tractS0 using "${src}census_tract_centroids_il", 
  t(n:1) unmatched(master) umatch(county tractid) uif(county==17031)
  ukeep(latitude longitude) urename(latitude latS0_mstr \ 
  longitude longS0_mstr);
  drop temp_tractS0 county;

** are the tracts that do not match generally nearby?;
  * note: 1 degree of latitude or longitude is approximately 70 miles;
  gen dist=(((latS0-latS0_mstr)*70)^2+((longS0-longS0_mstr)*70)^2)^.5;
  disp "** how far apart are the application and Master file tracts? **";
  summ dist if tractS0~=tractS0_mstr, detail;
  disp "** what fraction are within 1 mile if do not match? **"; 
  gen temp=(dist<=1) if dist~=. & tractS0~=tractS0_mstr;
  summ temp;
  disp "** what fraction are within 2 miles? **";
  replace temp=(dist<=2) if dist~=. & tractS0~=tractS0_mstr;
  summ temp;
  drop temp dist;

** make sure filled in (and constant) across idseq if ever exists;
 * !!Note: we use the master file tract if exists, and fill in using
   application geocode if not.  If we end up not focusing just on those 
   enrolled at the time they apply, we should not use the master file
   information because this would lead to selection as far as missing data, 
   since those applying from outside CPS do not have tractS0_mstr defined;

 disp "** fill in and check tract data across idseq **";
 egen temp1=mode(tractS0_mstr), by(idseq);
 egen temp2=mode(tractS0), by(idseq);
 egen temp3=max(tractS0), by(idseq);
 for num 2/3: replace temp1=tempX if temp1==.;
 * fill in block group, latitude and longitude;
 gen temp1b=groupS0 if tractS0==temp1;
 egen temp2b=max(temp1b), by(idseq);
 replace groupS0=temp2b;
 drop temp1b temp2b;
 for var latS0 longS0: gen temp1l=X_mstr if tractS0_mstr==temp1 \ 
  replace temp1l=X if tractS0==temp1 & temp1l==. \ 
  egen temp2l=max(temp1l), by(idseq) \ replace X=temp2l \ drop temp1l temp2l;
 * fill in tract;
 replace tractS0=temp1;
 drop temp* tractS0_mstr latS0_mstr longS0_mstr;
 
 disp "** make sure geographic data is constant within idseq **";
 summ tractS0 groupS0 latS0 longS0;
 for var tractS0 groupS0 latS0 longS0: egen temp=mean(X), by(idseq) \
  count if X~=temp \ drop temp;

/*** CENSUS DATA FROM SEMESTER OF APPLICATION ***/ 

** public assistance (1997);
if ${n}==0{; global src="CENSUS\"; };
if ${n}==1{; global src="e:\data\school_level\social_context\"; };
 label drop __MERGE;
 mmerge tractS0 using "${src}allpub", t(n:1) unmatched(master) umatch(tract)
 ukeep(total to697to to697af to697fo);
 disp "** AFDC / total assistance **";
 gen temp=to697af/to697to;
 summ temp, detail;
 disp "** food stamps / total assistance **";
 replace temp=to697fo/to697to;
 summ temp, detail;
 gen nnaidS0=to697to/total;
 summ nnaidS0, detail;
 replace nnaidS0=1 if nnaidS0>1 & nnaidS0~=.;
  label var nnaidS0 "nbhd: % on public assist in tract";
 drop to697* total temp;

** crime rate (1994);
gen double cenblock=170310000000+tractS0*1000+groupS0;
format cenblock %12.0f;
list cenblock in 1/10;
if ${n}==1{; global src="e:\data\school_level\social_context\"; };
 label drop __MERGE;
 mmerge cenblock using "${src}blcrim94", t(n:1) unmatched(master)
 ukeep(crime total) urename(crime nncrimS0);
* replace with population-weighted average across blocks in tract;
descr total;
gen temp1=nncrimS0;
sort tractS0 groupS0;
replace temp1=. if tractS0==tractS0[_n-1]&groupS0==groupS0[_n-1];
egen temp2=sum(total) if temp1~=., by(tractS0);
egen temp3=sum(temp1*total/temp2) if tractS0~=., by(tractS0);
summ nncrimS0 temp3;
corr nncrimS0 temp3;
replace nncrimS0=temp3;
 label var nncrimS0 "nbhd: composite crime in tract";
drop temp* groupS0 cenblock total;

** 2000 Census variables;
if ${n}==1{; global src="c:\projects\magnet schools\census\"; };
 label drop __MERGE;
 mmerge tractS0 using "${src}cens00tr", t(n:1) unmatched(master)
 umatch(trct00s) ukeep(totpop phispn pwhite pblack medhhinc povrate
 psingmom phsgrad psmcoll powner pvacant pnilf punemp pprv*)
 urename(totpop nnpopS0 \ phispn nnphisS0 \ pwhite nnpwhiS0 \ 
 pblack nnpblkS0 \ medhhinc nnmedyS0 \ povrate nnpovS0 \ psingmom nnfhdS0 \
 phsgrad nnhsgdS0 \ psmcoll nnsmclS0 \ powner nnownhS0\ pvacant nnvacS0 \ 
 pnilf nnnilfS0 \ punemp nnunemS0 \ pprvk8 nnprk8S0 \ pprv912 nnpr912S0 \
 pprvk12 nnprk12S0); 
 label var nnpopS0 "nbhd: total population in tract";
 label var nnphisS0 "nbhd: % Hispanic in tract";
 label var nnpwhiS0 "nbhd: % white in tract";
 label var nnpblkS0 "nbhd: % black in tract";
 label var nnmedyS0 "nbhd: median HH income in tract";
 label var nnpovS0 "nbhd: % in poverty in tract";
 label var nnfhdS0 "nbhd: % female headed fam in tract";
 label var nnhsgdS0 "nbhd: % 25+ yrs at least HS grad in tract";
 label var nnsmclS0 "nbhd: % 25+ yrs at least some coll in tract";
 label var nnownhS0 "nbhd: % units owned in tract";
 label var nnvacS0 "nbhd: % unit vacant in tract";
 label var nnnilfS0 "nbhd: % 16+ yrs out of labor force in tract"; 
 label var nnunemS0 "nbhd: % 16+ yrs unemp (if in LF) in tract";
 label var nnprk8S0 "nbhd: % private K-8 in tract";
 label var nnpr912S0 "nbhd: % private 9-12 in tract";
 label var nnprk12S0 "nbhd: % private k-12 in tract";

if ${n}==0{; global src=""; };
if ${n}==1{; global src="c:\projects\magnet schools\data\"; };
sort individ;
save "${src}magbase`1'", replace;

/*** DISTANCE TO PRIVATE SCHOOLS APPLICATION YEAR ***/

** get data for private schools in IL;
 if ${n}==0{; global src="GEOCODE\"; };
 if ${n}==1{; global src="c:\projects\magnet schools\geocode\"; };
 use schoolid name tractid longitude latitude tiger using "${src}IL_final_add";
 if ${n}==0{; global src=""; };
 if ${n}==1{; global src="c:\projects\magnet schools\data\"; };
 save "${src}temp_priv", replace;

** get data for private schools in IN;
 if ${n}==0{; global src="GEOCODE\"; };
 if ${n}==1{; global src="c:\projects\magnet schools\geocode\"; };
 use schoolid name tractid longitude latitude tiger using "${src}IN_final_add";
 if ${n}==0{; global src=""; };
 if ${n}==1{; global src="c:\projects\magnet schools\data\"; };
 append using "${src}temp_priv";

 * tracts need to be multiplied by 100 if from Tiger files;
 replace tractid=tractid*100 if tiger==1;
 rename longitude plong;
 rename latitude plat;

 * get rid of empty and duplicate observations;
 list if name=="";
 drop if name=="";
 egen double temp=mean(tractid), by(schoolid);
 list schoolid plat plong if tractid~=temp;
 * only one case where duplicates assigned to different tracts, but still
   assigned very similar latitudes and longitudes;
 sort schoolid;
 drop if schoolid==schoolid[_n-1];
 drop tiger name temp;

 * adjust schoolid to match other data set;
 gen temp=length(schoolid);
 tab temp;
 replace schoolid="0"+schoolid if temp==7;
 replace schoolid="00"+schoolid if temp==6;
 drop temp;

** only keep those private schools with 9th graders;
 disp "** should have 442 schools with 9th graders **";
 if ${n}==0{; global src="PRIV\"; };
 if ${n}==1{; global src="c:\projects\magnet schools\priv\"; };
 mmerge schoolid using "${src}all_priv", t(1:1) unmatched(none)
  uif(grade9_t~=.) ukeep(grade9_t county_no) urename(county_no county);

** add latitude and longitude for IL schools mapped by FFIEC;
 if ${n}==0{; global src="GEOCODE\"; };
 if ${n}==1{; global src="c:\projects\magnet schools\geocode\"; };
 label drop __MERGE;
  mmerge tractid county using "${src}census_tract_centroids_il",
  t(n:1) unmatched(master) ukeep(latitude longitude)
  urename(latitude plat2 \ longitude plong2);

** add latitude and longitude for IN schools mapped by FFIEC;
 label drop __MERGE;
  mmerge tractid county using "${src}census_tract_centroids_in",
  t(n:1) unmatched(master) ukeep(latitude longitude) 
  urename(latitude plat3 \ longitude plong3);

** replace missing data using lattitude and longitude by tract;
  summ plong plat if plat==0|plong==0;
  for var plong plat: replace X=. if X==0;
  summ plong* plat*;
  corr plat plat2;
  corr plong plong2;
  corr plat plat3;
  corr plong plong3;
  for var plong plat: replace X=X2 if X==. \ replace X=X3 if X==. \
   drop X2 X3;

 disp "** how many private schools with 9th graders weren't mapped? **";
 summ plong plat;
 gen temp1=(plong==.);
 summ temp1;
 gen temp2=int(county/1000);
 tab temp2;
 disp "** how many in IL weren't mapped? **";
 summ temp1 if temp2==17;
 disp "** how many in IN weren't mapped? **";
 summ temp1 if temp2==18;
 drop if temp1==1;
 drop temp* county tractid;

 summ;
 if ${n}==0{; global src=""; };
 if ${n}==1{; global src="c:\projects\magnet schools\data\"; };
 save "${src}temp_priv", replace;

** add geocoded applications data;
 use individ latS0 longS0 using "${src}magbase`1'";
 append using "${src}temp_priv";
 * put private school observations first;
 sort individ;
 list schoolid individ in 1;
 gen temp1=_n if schoolid~="";
 egen temp2=max(temp1);
 local j=temp2;
 for num 1/3: gen pri_milesX=.;
 for num 1/3: gen pri_enrX=0;
 gen dist=.;
 for num 1/`j', noheader: 
  qui replace dist=(((latS0-plat[X])*70)^2+((longS0-plong[X])*70)^2)^.5 \
  qui replace pri_miles3=dist if dist>pri_miles2 & dist<pri_miles3 \
  qui replace pri_miles3=pri_miles2 if dist<=pri_miles2 \
  qui replace pri_miles2=dist if dist>pri_miles1 & dist<pri_miles2 \
  qui replace pri_miles2=pri_miles1 if dist<=pri_miles1 \
  qui replace pri_miles1=dist if dist<pri_miles1 \
  qui replace pri_enr1=pri_enr1+grade9_t[X] if dist<=1 \
  qui replace pri_enr2=pri_enr2+grade9_t[X] if dist<=2.5 \
  qui replace pri_enr3=pri_enr3+grade9_t[X] if dist<=5;
 drop if individ=="";
 for var pri_*: replace X=. if latS0==. \ count if X==. & latS0~=.;
 keep individ pri_*;
 count if pri_miles2<pri_miles1;
 count if pri_miles3<pri_miles2;
 summ pri*;
  label var pri_miles1 "miles to nearest private school";
  label var pri_miles2 "miles to 2nd nearest private school";
  label var pri_miles3 "miles to 3rd nearest private school";
  label var pri_enr1 "9th grade enrollment at priv schs w/in 1 miles";
  label var pri_enr2 "9th grade enrollment at priv schs w/in 2.5 miles";
  label var pri_enr3 "9th grade enrollment at priv schs w/in 5 miles";
 save "${src}temp_priv", replace;

** add to base data set;
 use "${src}magbase`1'";
 label drop __MERGE;
 mmerge individ using "${src}temp_priv", t(1:1) unmatched(master)
 ukeep(pri_*);
 !del "${src}temp_priv.dta";

/*** TEST SCORE DATA FROM APPLICATION YEAR ***/

** ITBS files;
if ${n}==0{; global src=""; };
if ${n}==1{; global src="e:\data\itbs\"; };
 label drop __MERGE;
 mmerge sid using "${src}itbs`1'b", t(n:1) unmatched(master) 
 ukeep(sid readxil mathtxil) urename(readxil irdxilS0 \ mathtxil imtxilS0);

** TAP files;
if ${n}==1{; global src="e:\data\tap\"; };
 label drop __MERGE;
 mmerge sid using "${src}tap`2'", t(n:1) unmatched(master) 
 ukeep(sid readxil readge) urename(readxil trdxilS0 \ readge trdgeS0);

** also get ITBS test scores from year prior to application;
if ${n}==1{; global src="e:\data\itbs\"; };
 label drop __MERGE;
 mmerge sid using "${src}itbs`3'b", t(n:1) unmatched(master) 
 ukeep(sid readxil mathtxil) urename(readxil irdxil_1 \ mathtxil imtxil_1);

/*** SCHOOL-LEVEL INFORMATION FROM APPLICATION YEAR ***/

*** for school where enrolled in application year;

 * create main unit number;
 gen unitS0=int(curscS0/10)*10;
  label var unitS0 "unit enrolled in Spr Yr 0";

 * school type;
 if ${n}==0{; global src=""; }; 
 if ${n}==1{; global src="e:\data\school_level\misc\"; }; 
  label drop __MERGE;
  mmerge curscS0 using "${src}schl`2'", t(n:1) unmatched(master) 
  umatch(unit) ukeep(schlname schltype) urename(schlname uS0name \ 
  schltype uS0type);
   label var uS0name "school name in Spr Yr 0";
   label var uS0type "school type in Spr Yr 0";
 * note: 6170 is not in either the 2000 or the 2001 data set;
 tab unitS0 if _merge==1;
 drop curscS0;

 * school characteristics;
 if ${n}==1{; global src="e:\data\school_level\demo\"; };  
  label drop __MERGE;
  mmerge unitS0 using "${src}scinfo`2'", t(n:1) unmatched(master) 
  umatch(unit) ukeep(pwhite pblack phispn ploinc) urename(pwhite uS0pwhi \ 
  pblack uS0pblk \ phispn uS0phisp \ ploinc uS0ploinc);
   label var uS0pwhi "% white in sch Spr Yr 0";
   label var uS0pblk "% black in sch Spr Yr 0";
   label var uS0phisp "% hispanic in sch Spr Yr 0";
   label var uS0ploinc "% low income in sch Spr Yr 0";
  disp "** which Spring schools have no match in scinfo{yr}.dta? **";
  tab unitS0 if _merge==1;
  * fill in for one missing in 2001 that is in 2000 data;
  for any whi blk hisp loinc \ any .2 79.6 20.2 93: 
   replace uS0pX=Y if unitS0==7400 & uS0pX==.;

  * use 2001 data to fill in for missing data in 2000;
  if `1'==2000{;
  label drop __MERGE;
  mmerge unitS0 using "${src}scinfo01", t(n:1) unmatched(master) 
  umatch(unit) ukeep(pwhite pblack phispn ploinc) urename(pwhite tS0pwhi \ 
  pblack tS0pblk \ phispn tS0phisp \ ploinc tS0ploinc);
  disp "** which Spr schools only in later year for scinf*.dta? **";
  tab unitS0 if tS0pwhi~=. & uS0pwhi==.;
  for any pwhi pblk phisp ploinc: replace uS0X=tS0X if uS0X==.;
  drop tS0*;
  };

 * ITBS average achievement;
 * note: 2 schools have different ID's in test score data sets than in
   other data files and have both TAPS and ITBS results.  The TAPS and ITBS 
   results are highly correlated, and we use the ITBS results;
 * note: we use reading scores to characterize schools, the overall 
   correlation between the % above norms on math and reading is 0.94;
 gen tempunit=unitS0;
 * Dyett is normally 8070, and Hope Coll Prep is normally 4130;
 replace tempunit=1600 if unitS0==8070;
 replace tempunit=1940 if unitS0==4130;
  if ${n}==1{; global src="e:\data\school_level\tests\"; }; 
  label drop __MERGE;
  mmerge tempunit year using "${src}itbs19972002.dta", t(n:1) 
  unmatched(master) umatch(unit year) uif(subject=="read") 
  ukeep(subject pnorms) urename(pnorms uS0itbs);
   label var uS0itbs "% above ITBS reading norms";
  disp "** which Spring elem schools have no match in ITBS data? **";
  tab unitS0 if _merge==1 & unitS0>=2000;
  * can fill in for some of these using closest (in time) existing value;
  replace uS0itbs=9.4 if unitS0==4730 & uS0itbs==.;
  replace uS0itbs=15.3 if unitS0==7400 & uS0itbs==.;
 drop subject tempunit;

 * school selectivity;
 if ${n}==1{; global src="c:\projects\magnet schools\data\"; };
  label drop __MERGE;
  mmerge unitS0 using "${src}schselectivity", t(n:1) unmatched(master)
  umatch(unit) ukeep(mnotaa) urename(mnotaa uS0mnotaa);
   label var uS0mnotaa "% not AA students 2-year avg";
  disp "** which Spring schools have no match in selectivity data? **";
  tab unitS0 if _merge==1;

*** for "choice" school-- that is, the school to which student applied;

 * first adjust unit number;
 disp "** how many choice unit numbers are not main unit numbers? **";
 gen holdunit=cunit;
 gen temp=int(cunit/10)*10;
 tab cunit if temp~=cunit;
 replace cunit=temp;
 drop temp;
 
 * school type;
 if ${n}==0{; global src=""; }; 
 if ${n}==1{; global src="e:\data\school_level\misc\"; }; 
  label drop __MERGE;
  mmerge holdunit using "${src}schl`2'", t(n:1) unmatched(master) 
  umatch(unit) ukeep(schlname schltype) urename(schlname cuname \ 
  schltype cutype);
  disp "** which application schools have no match in schl`2'.dta? **";
  tab cunit if _merge==1;
  replace cuname="PAYTON COLLEGE PREP HS" if cuname=="" & cunit==1090;
  replace cutype="College Prep" if cutype=="" & cunit==1090;
  * The Chicago Academy is the city's first contract school (neighborhood
  school that is a school-based teacher prep program);
  replace cuname="CHICAGO ACADEMY" if cunit==6670;
  replace cutype="General" if cunit==6670;

* school budget data;
  if ${n}==1{; global src="e:\data\budget\"; };
   label drop __MERGE;
   mmerge cunit year using "${src}allschbud", t(n:1) unmatched(master)
   umatch(unit year) 
   ukeep(totd totp size p_sped ppe par ptr pir p_title1 p_pers p_npers p_i);
   descr totd totp size p_sped ppe par ptr pir p_title1 p_pers p_npers p_i;
   sort cunit;
   list cunit cuname if _merge==1 & cunit~=cunit[_n-1];
   summ totd totp size p_sped ppe par ptr pir p_title1 p_pers p_npers p_i;
   * there are no non-regular choice schools (other than Spalding and King);
   tab cutype, miss;
   * note: none of the extreme outliers (e.g. Spalding and King) are included 
   in our analysis in any case;
   * note: Farren (3300) shows dramatic changes in 2001, but appears to still
   be a regular school;
   summ ppe, detail;
   sort cunit;
   list cuname cunit ppe p_sped par if ppe>10000 & ppe~=. & cunit~=cunit[_n-1];
   summ p_sped if ppe<10000;
   for any ppe par ptr: rename X cuX;
   rename p_sped cupsped;
   sum cuppe cupar cuptr cupsped;
   drop totd totp size pir p_title1 p_pers p_npers p_i;

 * teacher characteristics (from 1998-99 school year); 
 * note: missing for schools with unit numbers >= 2000;
   if ${n}==1{; global src="c:\projects\magnet schools\data\"; }; 
   label drop __MERGE;
   mmerge cunit using "${src}tchrs99", t(n:1) unmatched(master) umatch(unit) 
   ukeep(univ* mstdum1 phddum1 scrths educmjr scrtsub tcrt tcps tpos age nfte);
   sort cunit;
   list cunit cuname if _merge==1 & cunit<2000 & cunit~=cunit[_n-1];
   descr univ* mstdum1 phddum1 scrths educmjr scrtsub tcrt tcps tpos age nfte;
   gen mstpls=mstdum1+phddum1;
    label var mstpls "teachers w/MA or PhD";
   for any univ1 univmeas mstpls scrths educmjr scrtsub tcrt: rename X cuX;
   drop univ2 univ3 univ4 univ5 univelse mstdum1 phddum1 age tcps tpos nfte;
   sum cuuniv1 cuunivmeas cumstpls cuscrths cueducmjr cuscrtsub cutcrt;
   corr cuuniv1 cuunivmeas cumstpls cuscrths cueducmjr cuscrtsub cutcrt;

 * school characteristics;
 if ${n}==1{; global src="e:\data\school_level\demo\"; }; 
  label drop __MERGE;
  mmerge cunit using "${src}scinfo`2'", t(n:1) unmatched(master) 
  umatch(unit) ukeep(pwhite pblack phispn lep ploinc pattnd size pdrop pgrad) 
  urename(pwhite cupwhi \ pblack cupblk \ phispn cuphisp \ lep cuplep \ 
  ploinc cuploinc \ pattnd cupattnd \ size cusize \ pdrop cupdrop \ 
  pgrad cupgrad);
  capture replace cusize=subinstr(cusize,",","",.);
  capture gen temp=real(cusize);
  capture gen temp=cusize;
  drop cusize;
  rename temp cusize;
   label var cusize "total enrollment";
  disp "** which application schools have no match in scinfo`2'.dta? **";
  tab cunit if _merge==1;
  * note: no information on 6670 available;
  * use 2001 data for 2000 cases with missing information;
  for any pwhi pblk phisp plep ploinc pattnd size pdrop pgrad \ 
  any 28 33.7 30.7 0 37.2 94.6 371 1.3 .: replace cuX=Y if cuX==.&cunit==1090;
  for any pwhi pblk phisp plep ploinc pattnd size pdrop pgrad \ 
  any 5 78.8 15 1.5 83.4 81 481 10.2 75: replace cuX=Y if cuX==.&cunit==1650;
  for any pwhi pblk phisp plep ploinc pattnd size pdrop pgrad \ 
  any 51.7 7.5 16.4 .4 24.3 94.3 756 3.3 100: replace cuX=Y if cuX==.
    &cunit==1740;
  for any pwhi pblk phisp plep ploinc pattnd size pdrop pgrad \ 
  any 1.5 72.5 25.2 16.8 87 84.3 131 . .: replace cuX=Y if cuX==.&cunit==5990;

 * ITBS average achievement;
 gen tempunit=cunit;
 * Dyett is normally 8070, and Hope Coll Prep is normally 4130;
 replace tempunit=1600 if cunit==8070;
 replace tempunit=1940 if cunit==4130;
 if ${n}==1{; global src="e:\data\school_level\tests\"; }; 
   label drop __MERGE;
   mmerge tempunit year using "${src}itbs19972002.dta", t(n:1) 
   unmatched(master) umatch(unit year) uif(subject=="read") ukeep(subject
   pnorms) urename(pnorms cuitbs);
   disp "** which elem application schools have no match in ITBS data? **";
   tab cunit if _merge==1 & cunit>=2000;
   * use closest year data to fill in for missing;
   replace cuitbs=81.8 if cunit==6670 & cuitbs==.;
  drop tempunit;

 * TAPS average achievement;
  * note: merge on (n:n) because duplicate unit-subject-year obs in 1999;
  label drop __MERGE;
  mmerge cunit year using "${src}tap19912002.dta", t(n:n) 
  unmatched(master) umatch(unit year) uif(subject=="read") 
  ukeep(pnorms subject) urename(pnorms cutap);
  disp "** which application high schools have no match in TAPS data? **";
  tab cuname if _merge==1 & cunit<2000;

 * replace with later data for those high schools that recently opened;
  gen tempyr=2002;
  label drop __MERGE;
  mmerge cunit tempyr using "${src}tap19912002.dta", t(n:n) 
  unmatched(master) umatch(unit year) uif(subject=="read") 
  ukeep(pnorms subject) urename(pnorms holdcutap);
  disp "** which application high schools only have later TAPS data? **";
  tab cuname if _merge==3 & cunit<2000 & cutap==. & holdcutap~=.;
  replace cutap=holdcutap if cutap==. & cunit<2000;
  drop tempyr holdcutap;

 * combining these;
 gen cupnorms=cuitbs if cunit>=2000;
 replace cupnorms=cutap if cunit<2000;
  label var cupnorms "% above reading norms";
 drop subject cuitbs cutap;
  
 * selectivity;
 if ${n}==1{; global src="c:\projects\magnet schools\data\"; };
  label drop __MERGE;
  mmerge cunit using "${src}schselectivity.dta", t(n:1) unmatched(master)
  umatch(unit) ukeep(mnotaa) urename(mnotaa cumnotaa);
  label var cumnotaa "% not AA students 2-year avg";

 * Census data;
 if ${n}==0{; global src="GEOCODE\"; }; 
 if ${n}==1{; global src="c:\projects\magnet schools\geocode\"; }; 
  label drop __MERGE;
  mmerge holdunit year using "${src}pub_geo", t(n:1) unmatched(master) 
  umatch(unit year) ukeep(trct00s) urename (trct00s cutract);
   label var cutract "2000 tract for appl school";
  disp "** which application schools missing tract data? **";
  tab cunit if _merge==1;
  * note: unit 1090 is in 2001 data, but wasn't successfully mapped;
  drop holdunit;

 * use tract-level crime data;
 sort tractS0;
 gen temp1=1 if tractS0~=tractS0[_n-1] & tractS0~=.;
 sort temp1;
 gen temp2=_n if temp1==1;
 egen temp3=max(temp2);
 local j=temp3;
 gen cucrim=.;
 for num 1/`j', noheader: 
  qui replace cucrim=nncrim[X] if cutract==tractS0[X];
  label var cucrim "composite crime in tract";
 disp "** are any choice units missing crime information? **";
 tab cutract if cucrim==.;
 replace cucrim=-.3662406 if cutract==3509 & cucrim==.;
 drop temp*;

 if ${n}==0{; global src="CENSUS\"; }; 
 if ${n}==1{; global src="c:\projects\magnet schools\census\"; };
 label drop __MERGE;
 mmerge cutract using "${src}cens00tr", t(n:1) unmatched(master)
  umatch(trct00s) ukeep(medhhinc povrate) urename (medhhinc cumedy \
  povrate cupov);
  label var cumedy "median HH income in tract";
  label var cupov "% in poverty in tract";
 disp "** which application schools (w/tract) missing Census data? **";
 tab cunit if _merge==1;

 * Distance from home to choice school in Spring Yr 0 - centroid of tracts ;
 * origin=spring home tract, destination=choice school tract; 
 if ${n}==0{; global src="GEOCODE\"; };
 if ${n}==1{; global src="e:\data\school_level\census\"; }; 
 label drop __MERGE;
 mmerge tractS0 cutract using "${src}tracttotractdistances", t(n:1) 
 ukeep(miles) umatch(tract_o tract_d) unmatched(master) missing(nomatch) 
 urename(miles cumiles);
 count if cumiles==. & tractS0~=. & cutract~=.;
  label var cumiles "home-school distance in Spr Yr 0";

/*** ENROLLMENT DATA FROM FALL FOLLOWING APPLICATION ***/

** get status variable for all students;
if ${n}==0{; global src=""; };
if ${n}==1{; global src="e:\fullmasterfiles\"; }; 
 label drop __MERGE;
 mmerge sid using "${src}allm9`2'full", t(n:1) unmatched(master) 
 ukeep(statu9`2' lvrea9`2') urename(statu9`2' holdstatuF1 \
  lvrea9`2' lvreaF1); 

** get other variables for students enrolled in Fall;
 * note: bilingual and free lunch status only available in Spring;
 label drop __MERGE;
 mmerge sid using "${src}allm9`2'full", t(n:1) unmatched(master) 
 uif(statu9`2'==1|statu9`2'==2)
 ukeep(centract statu9`2' granu9`2' guard9`2' sped9`2' cursc9`2')
 urename(centract tractF1 \ statu9`2' statuF1 \ granu9`2' gradeF1 \ 
 guard9`2' guardF1 \ sped9`2' spedF1 \ cursc9`2' curscF1);

 tab holdstatuF1 if statuF1==.;
 replace statuF1=holdstatuF1 if statuF1==.;
 drop holdstatuF1;
 replace tractF1=tractF1-170310000;
  label var tractF1 "student's tract in Fall Yr 1";
 summ tractF1;

/*** INFORMATION ABOUT THE FALL SCHOOL ***/

 * adjust unit number;
 disp "** how many Fall unit numbers are not main unit numbers? **";
 gen unitF1=int(curscF1/10)*10;
 tab curscF1 if unitF1~=curscF1;

 * school type;
 if ${n}==0{; global src=""; };
 if ${n}==1{; global src="e:\data\school_level\misc\"; }; 
  label drop __MERGE;
  mmerge curscF1 using "${src}schl`2'", t(n:1) unmatched(master) 
  umatch(unit) ukeep(schlname schltype) urename(schlname uF1name \ 
  schltype uF1type);
  replace uF1type="General" if unitF1==2920 & uF1type=="";
  disp "** which Fall Yr 1 schools have no match in schl`2'.dta? **";
  tab unitF1 if _merge==1;
  replace uF1name="PAYTON COLLEGE PREP HS" if unitF1==1090;
  replace uF1name="ARMOUR" if unitF1==2070;
  replace uF1name="CHGO INTL CHRT ST ED" if unitF1==2290;
  replace uF1name="NEW DAWES AREA" if unitF1==2350;
  replace uF1name="YNG WOMN LDRSHP CHRT" if unitF1==2490;
  replace uF1name="DYETT MIDDLE" if unitF1==1600;
  replace uF1name="DAVIS/SHIELDS" if unitF1==5860;
  replace uF1name="COLEMAN, J" if unitF1==6170;
  replace uF1name="GV CHILD CHOIR CHART" if unitF1==6530;
  replace uF1name="CHICAGO ACADEMY" if unitF1==6670;
  replace uF1name="LEARN CHARTER" if unitF1==6770;
  replace uF1name="GV PASSAGES CHARTER" if unitF1==6850;
  for num 1090 2070 2290 2350 2490 6530 6670 6770 6850 \ 
   any "College Prep" "General" "Charter" "General" "Charter" "Charter"
   "General" "Charter" "Charter": replace uF1type="Y" if unitF1==X;

 * school budget data;
  if ${n}==1{; global src="e:\data\budget\"; }; 
  label drop __MERGE;
  mmerge unitF1 year using "${src}allschbud", t(n:1) unmatched(master) 
  umatch(unit year) 
  ukeep(totd totp size p_sped ppe par ptr pir p_title1 p_pers p_npers p_i);
  sort unitF1;
  list unitF1 uF1name if unitF1~=unitF1[_n-1] & unitF1~=. & _merge~=3;

  sum totd totp size p_sped ppe par ptr pir p_title1 p_pers p_npers p_i;
  * Note: there are some outrageous values here, as documented in the 
    data creation program.  The main problem are schools with low ppe and
    few, if any, allocated positions.  Here we set these data to missing;
  sum ppe, d;
  * most, if not all, of these schools are charters;
  sort unitF1;
  list unitF1 uF1name uF1type ppe p_sped if ppe<3000 & unitF1~=unitF1[_n-1];
  tab uF1type if unitF1~=. & ppe~=., miss; 
  * We set budget variables to missing for all "non-regular" school types (as 
    well as all schools with per pupil expenditures below $3000);
  * note: 1650 and 5990 are Spalding High and Elementary special ed schools;
  for var totd totp size par ptr pir p_title1 p_pers p_npers p_i ppe p_sped: 
   replace X=. if (uF1type=="Academic Prep Center"|uF1type=="Alt-Pregnant Girls"|
   uF1type=="Alternative"|uF1type=="Charter"|uF1type=="Child Parent Center"|
   uF1type=="Jail/Juv Detention"|uF1type=="Phys. Handicapped"|uF1type=="PreKdg"|
   uF1type=="Special Education"|uF1type=="Special Needs"|
   uF1type=="Tuition Placement")|(p_sped>.5&p_sped~=.)|(ppe<3000|ppe==.);
  tab uF1type if ppe~=.;
  for var ppe par ptr: rename X uF1X;
  rename p_sped uF1psped;
  sum uF1ppe uF1par uF1ptr uF1psped;
  corr uF1ppe uF1par uF1ptr uF1psped;
  drop totd totp size pir p_title1 p_pers p_npers p_i;

 * teacher characteristics; 
  if ${n}==1{; global src="c:\projects\magnet schools\data\"; }; 
  label drop __MERGE;
  mmerge unitF1 using "${src}tchrs99", t(n:1) unmatched(master) umatch(unit) 
  ukeep(univ* mstdum1 phddum1 scrths educmjr scrtsub tcrt tcps tpos age nfte);
  tab unitF1 if _merge==1 & unitF1<2000;
  gen mstpls=mstdum1+phddum1;
   label var mstpls "teachers w/MA or PhD";
  for any univ1 univmeas mstpls scrths educmjr scrtsub tcrt: rename X uF1X; 
  drop univ2 univ3 univ4 univ5 univelse mstdum1 phddum1 tcps tpos age nfte;
  sum uF1univ1 uF1univmeas uF1mstpls uF1scrths uF1educmjr uF1scrtsub uF1tcrt;
  tab uF1type if uF1univ1~=. & uF1ppe==.;
  tab uF1name if uF1univ1~=. & uF1ppe==. & uF1type=="General";
  for any univ1 univmeas mstpls scrths educmjr scrtsub tcrt: replace uF1X=. if uF1ppe==.;
  corr uF1univ1 uF1univmeas uF1mstpls uF1scrths uF1educmjr uF1scrtsub uF1tcrt;

 * school characteristics;
 if ${n}==1{; global src="e:\data\school_level\demo\"; }; 
  label drop __MERGE;
  mmerge unitF1 using "${src}scinfo`2'", t(n:1) unmatched(master) 
  umatch(unit) ukeep(pwhite pblack phispn lep ploinc pattnd size pdrop pgrad) 
  urename(pwhite uF1pwhi \ pblack uF1pblk \ phispn uF1phisp \ lep uF1plep \ 
  ploinc uF1ploinc \ pattnd uF1pattnd \ size uF1size \ pdrop uF1pdrop \ 
  pgrad uF1pgrad);
  capture replace uF1size=subinstr(uF1size,",","",.);
  capture gen temp=real(uF1size);
  capture gen temp=uF1size;
  drop uF1size;
  rename temp uF1size;
   label var uF1size "total enrollment";
  disp "** which Fall Yr 1 schools have no match in scinfo`2'.dta? **";
  tab unitF1 if _merge==1;
  * fill in using 2000 data for unit 7400 in 2001;
  for any pwhi pblk phisp plep ploinc pattnd size pdrop pgrad \ 
   any .2 79.6 20.2 12.6 93 87.4 445 . .: replace uF1X=Y if unitF1==7400;

 * use 2001 data for schools missing in 2000 file;
  if `1'==2000{;
  label drop __MERGE;
  mmerge unitF1 using "${src}scinfo`6'", t(n:1) unmatched(master) 
  umatch(unit) ukeep(pwhite pblack phispn lep ploinc pattnd size pdrop pgrad) 
  urename(pwhite tF1pwhi \ pblack tF1pblk \ phispn tF1phisp \ lep tF1plep \ 
  ploinc tF1ploinc \ pattnd tF1pattnd \ size tF1size \ pdrop tF1pdrop \ 
  pgrad tF1pgrad);
  disp "** which Fall schools only in later year for scinf*.dta? **";
  tab unitF1 if tF1pwhi~=. & uF1pwhi==.;
  for any pwhi pblk phisp plep ploinc pattnd size pdrop pgrad: 
     replace uF1X=tF1X if uF1X==.;
  drop tF1*;
  };

 * average ITBS achievement (using prior year Spring data);
 gen tempunit=unitF1;
 * Dyett is normally 8070, and Hope Coll Prep is normally 4130;
 replace tempunit=1600 if unitF1==8070;
 replace tempunit=1940 if unitF1==4130;
 if ${n}==1{; global src="e:\data\school_level\tests\"; }; 
  label drop __MERGE;
  mmerge tempunit year using "${src}itbs19972002", t(n:1) 
  unmatched(master) umatch(unit year) uif(subject=="read") 
  ukeep(subject pnorms) urename(pnorms uF1itbs);
 disp "** which Fall elem schs are missing ITBS scores? **";
 tab unitF1 if unitF1>=2000 & _merge==1;
 * fill in using closest year data existing for those missing 2000 data;
 for num 2290 2350 2490 4730 \ any 31.3 45.8 56.9 9.4:
  replace uF1itbs=Y if unitF1==X & uF1itbs==. & `1'==2000;

 * replace with later data for those elem schools that recently opened;
  gen tempyr=2002;
  label drop __MERGE;
  mmerge tempunit tempyr using "${src}itbs19972002", t(n:1) 
  unmatched(master) umatch(unit year) uif(subject=="read") 
  ukeep(subject pnorms) urename(pnorms holduF1itbs);
  disp "** which Fall Yr 1 elem schools only have later ITBS data? **";
  tab unitF1 if unitF1>=2000 & uF1itbs==. & holduF1itbs~=.;
  replace uF1itbs=holduF1itbs if unitF1>=2000 & uF1itbs==.;
  drop holduF1itbs tempunit;

 * average TAPS; 
  label drop __MERGE;
  mmerge unitF1 year using "${src}tap19912002.dta", t(n:n) 
  unmatched(master) umatch(unit year) uif(subject=="read") 
  ukeep(subject pnorms) urename(pnorms uF1tap);

 * replace with later data for those high schools that recently opened;
  label drop __MERGE;
  mmerge unitF1 tempyr using "${src}tap19912002.dta", t(n:n) 
  unmatched(master) umatch(unit year) uif(subject=="read") 
  ukeep(subject pnorms) urename(pnorms holduF1tap);
  disp "** which Fall Yr 1 high schools only have later TAPS data? **";
  tab unitF1 if unitF1<2000 & uF1tap==. & holduF1tap~=.;
  replace uF1tap=holduF1tap if unitF1<2000 & uF1tap==.;
  drop tempyr holduF1tap;

  * combine ITBS and TAPS;
  gen uF1pnorms=uF1itbs if unitF1>=2000&unitF1!=.;
  replace uF1pnorms=uF1tap if unitF1<2000&unitF1!=.;
   label var uF1pnorms "% above reading norms";
  drop uF1itbs uF1tap subject;
 
 * selectivity;
 if ${n}==1{; global src="c:\projects\magnet schools\data\"; };
  label drop __MERGE;
  mmerge unitF1 using "${src}schselectivity.dta", t(n:1) unmatched(master)
  umatch(unit) ukeep(mnotaa) urename(mnotaa uF1mnotaa);
  label var uF1mnotaa "% not AA students 2-year avg";

 * Census data;
 if ${n}==0{; global src="GEOCODE\"; }; 
 if ${n}==1{; global src="c:\projects\magnet schools\geocode\"; }; 
  label drop __MERGE;
  mmerge curscF1 year using "${src}pub_geo", t(n:1) unmatched(master) 
  umatch(unit year) ukeep(trct00s) urename (trct00s uF1tract);
  disp "** which Fall Yr 1 schools missing tract data? **";
  tab unitF1 if _merge==1;
  * fill in ones that can;
  for num 2070 2290 2350 \ num 6008 4008 7001:
   replace uF1tract=Y if unitF1==X & uF1tract==.;
  drop curscF1;

 * use tract-level crime data;
 sort tractS0;
 gen temp1=1 if tractS0~=tractS0[_n-1] & tractS0~=.;
 sort temp1;
 gen temp2=_n if temp1==1;
 egen temp3=max(temp2);
 local j=temp3;
 gen uF1crim=.;
 for num 1/`j', noheader: 
  qui replace uF1crim=nncrim[X] if uF1tract==tractS0[X];
  label var uF1crim "composite crime in blk grp";
 disp "** are any Fall schools missing crime information? **";
 tab uF1tract if uF1crim==.;
 replace uF1crim=-.3662406 if uF1tract==3509 & uF1crim==.;
 replace uF1crim=6.890952 if uF1tract==3204 & uF1crim==.;
 drop temp*;

 * neighborhood data;
 if ${n}==0{; global src="CENSUS\"; }; 
 if ${n}==1{; global src="c:\projects\magnet schools\census\"; };
  label drop __MERGE;
  mmerge uF1tract using "${src}cens00tr", t(n:1) unmatched(master)
   umatch(trct00s) ukeep(medhhinc povrate) urename(medhhinc uF1medy \
   povrate uF1pov);
   label var uF1medy "median HH income in tract";
   label var uF1pov "% in poverty in tract";
  disp "** which Fall Yr 1 schools missing Census data? **";
  tab unitF1 if _merge==1;

  * Distance from home to school in Fall Yr 1 - centroid of tracts ;
  * origin=fall home tract, destination=fall school tract; 
  if ${n}==0{; global src="GEOCODE\"; };
  if ${n}==1{; global src="e:\data\school_level\census\"; }; 
  label drop __MERGE;
  mmerge tractF1 uF1tract using "${src}tracttotractdistances", t(n:1) 
   ukeep(miles) umatch(tract_o tract_d) unmatched(master) missing(nomatch) 
   urename(miles uF1miles);
   label var uF1miles "home-school distance in Fall Yr 1";
  count if uF1miles==. & tractF1~=. & uF1tract~=.;

  * Same using home location in Spring Yr 0;
  * origin=spring home tract, destination=fall school tract; 
  label drop __MERGE;
  mmerge tractS0 uF1tract using "${src}tracttotractdistances", t(n:1) 
   ukeep(miles) umatch(tract_o tract_d) unmatched(master) missing(nomatch) 
   urename(miles uF1miles_0);
   label var uF1miles_0 "Spr Yr 0 home-Fall Yr 1 school distance";
  count if uF1miles_0==. & tractS0~=. & uF1tract~=.;

/*** SPRING YEAR 1 DATA TO LOOK AT IMPACTS ***/

** Spring Year 1 master file;

if ${n}==0{; global src=""; };
if ${n}==1{; global src="e:\fullmasterfiles\"; }; 
 label drop __MERGE;
 mmerge sid using "${src}allm5`6'full", t(n:1) unmatched(master) 
 ukeep(sid statu5`6' lvrea5`6' granu5`6' guard5`6' sped5`6' cursc5`6'
 bcat5`6' lunch5`6' aunit5`6') urename(statu5`6' statuS1 \ lvrea5`6' lvreaS1 \
 granu5`6' gradeS1 \ guard5`6' guardS1 \ sped5`6' spedS1 \ cursc5`6' curscS1 \
 bcat5`6' bcatS1 \ lunch5`6' lunchS1 \ aunit5`6' aunitS1);

** ITBS & TAP data;

if ${n}==1{; global src="e:\data\itbs\"; }; 
 label drop __MERGE;
 mmerge sid using "${src}itbs`5'b", t(n:1) unmatched(master) 
 ukeep(sid readxil mathtxil) urename(readxil irdxilS1 \ mathtxil imtxilS1);

* note: the math TAP was not given after 1999 because they are phasing out
the exams, so we just look at reading for TAP;
if ${n}==1{; global src="e:\data\tap\"; }; 
 if `1'==2000{;
  label drop __MERGE;
  mmerge sid using "${src}tap01", t(n:1) unmatched(master) 
  ukeep(sid readxil readge) urename(readxil trdxilS1 \ readge trdgeS1);
  };
 if `1'==2001{;
  label drop __MERGE;
  mmerge sid using "${src}tap2002b", t(n:1) unmatched(master) 
  ukeep(sid readxil readge) urename(readxil trdxilS1 \ readge trdgeS1);
  };

** Spring Year 1 Case Exam Files;

* note: only pulling exams that are most commonly taken in Spring Year 1 
 (9th grade).  These are biology, world, algebra, and English 1;
if ${n}==0{; global src="CASE_EXAMS\"; };
if ${n}==1{; global src="c:\projects\magnet schools\case_exams\"; }; 
 label drop __MERGE;
 mmerge sid using "${src}case`5's", t(n:1) unmatched(master) 
 ukeep(sid cs_alg_mpct cs_alg_cpct cs_alg_tpct
 cs_eng1_mpct cs_eng1_cpct cs_eng1_tpct cs_wld_mpct cs_wld_cpct cs_wld_tpct
 cs_bio_mpct cs_bio_cpct cs_bio_tpct);  
 for any alg eng1 wld bio: rename cs_X_mpct XmpS1 \
 rename cs_X_cpct XcpS1 \ rename cs_X_tpct XtpS1 \
 replace XmpS1=XmpS1/100 \ replace XcpS1=XcpS1/100 \ replace XtpS1=XtpS1/100;

** Spring Year 1 high school transcript files;

if ${n}==0{; global src=""; };
if ${n}==1{; global src="e:\data\transcripts\"; }; 
 label drop __MERGE;
 mmerge sid using "${src}grspr`6'new", t(n:1) unmatched(master) 
 ukeep(sid ranksp`6' clszsp`6' gpasp`6' 
 abs1sp`6' abs2sp`6' abs3sp`6' abs4sp`6' abs5sp`6' abs6sp`6' abs7sp`6' 
 abs8sp`6' abs9sp`6' abs0sp`6'
 crd1sp`6' crd2sp`6' crd3sp`6' crd4sp`6' crd5sp`6' crd6sp`6' crd7sp`6' 
 crd8sp`6' crd9sp`6' crd0sp`6'
 fmk1sp`6' fmk2sp`6' fmk3sp`6' fmk4sp`6' fmk5sp`6' fmk6sp`6' fmk7sp`6' 
 fmk8sp`6' fmk9sp`6' fmk0sp`6');
	
 rename gpasp`6' gpaS1;
 summ abs*;
 egen mabsS1=rmean(abs1sp`6' abs2sp`6' abs3sp`6' abs4sp`6' abs5sp`6' 
      abs6sp`6' abs7sp`6' abs8sp`6' abs9sp`6' abs0sp`6');
 egen tcrdS1=rsum(crd1sp`6' crd2sp`6' crd3sp`6' crd4sp`6' crd5sp`6' 
      crd6sp`6' crd7sp`6' crd8sp`6' crd9sp`6' crd0sp`6');
  gen temp=0;
  for num 1/9 0: replace temp=1 if crdXsp`6'~=.;
  replace tcrdS1=. if temp==0;
  drop temp;
 egen anyfS1=rany(fmk1sp`6' fmk2sp`6' fmk3sp`6' fmk4sp`6' fmk5sp`6' 
      fmk6sp`6' fmk7sp`6' fmk8sp`6' fmk9sp`6' fmk0sp`6'), c(@=="F");
 egen numfS1=rcount(fmk1sp`6' fmk2sp`6' fmk3sp`6' fmk4sp`6' fmk5sp`6' 
      fmk6sp`6' fmk7sp`6' fmk8sp`6' fmk9sp`6' fmk0sp`6'), c(@=="F");
  gen temp=0;
  for num 1/9 0: replace temp=1 if fmkXsp`6'~="";
  for var anyfS1 numfS1: replace X=. if temp==0;
  drop temp;
 gen crankS1=round((ranksp`6'/clszsp`6')*100,.1);
 drop ranksp`6' clszsp`6' abs* crd* fmk*;

 label var gpaS1 "Cumulative GPA Spr Yr 1";
 label var mabsS1 "Average course absences Spr Yr 1";
 label var tcrdS1 "Total credits earned Spr Yr 1";
 label var anyfS1 "At least 1 F Spr Yr 1";
 label var numfS1 "Total # of Fs Spr Yr 1";
 label var crankS1 "Class rank Spr Yr 1";

/*** CHARACTERIZING ATTENDANCE AREA SCHOOL (Spring Year 1) ***/

 ** we are assuming this proxies fairly well for Fall AA school;

 disp "** identify AA for students not in CPS in Spring Yr 1 **";
 * note: we use information on AA for students in the same tract and grade
   in Spring Yr 0.  This does not allow us to fill in missing information
   for students applying from outside the CPS, but that is okay for our
   purposes; 
 summ aunitS1;
 replace aunitS1=. if aunitS1==0;
 count if curscS1==. & aunitS1~=.;
 count if curscS1~=. & aunitS1==.;
 disp "** find modal AA by Spring Yr 0 tract **";
 gen tmp1=aunitS1 if gradeS1==gradeS0+1 & gradeS0~=.;
 egen tmp2=mode(tmp1) if tractS0~=., by(tractS0 gradeS0);
 disp "** what fraction of students assigned modal AA by tractS0? **"; 
 egen tmp3=mean(tmp1==tmp2) if tmp1~=. & tmp2~=. & tractS0~=., 
  by(gradeS0 tractS0);
 summ tmp3, detail;
 * arbitarily pick maximum if there are multiple modes;
 egen tmp4=mode(tmp1) if tractS0~=., by(tractS0 gradeS0) maxmode;
 replace tmp2=tmp4 if tmp2==.;
 summ tmp1 if tmp2==. & tractS0~=.;
 disp "** how often does modal AA and actual AA differ? **";
 gen tmp5=(tmp2~=tmp1) if tmp2~=. & tmp1~=.;
 summ tmp5;
 tabstat tmp5 if gradeS0<10, by(gradeS0);
 replace aunitS1=tmp2 if aunitS1==.;
 disp "** how often unable to assign an AA for CPS applicants? **";
 tab gradeS0 if aunitS1==.;
 drop tmp*;

 * adjust unit number;
 gen holdunit=aunitS1;
 replace aunitS1=int(aunitS1/10)*10;

 * school type;
 if ${n}==0{; global src=""; };
 if ${n}==1{; global src="e:\data\school_level\misc\"; }; 
  label drop __MERGE;
  mmerge holdunit using "${src}schl`2'", t(n:1) unmatched(master) 
  umatch(unit) ukeep(schlname schltype) urename(schlname aS1name \ 
  schltype aS1type);
  disp "** which AA schools have no match in schl`2'.dta? **";
  tab aunitS1 if _merge==1;
  replace aS1name="NEW DAWES AREA" if aunitS1==2350;
  replace aS1name="DAVIS/SHIELDS" if aunitS1==5860;
  replace aS1type="General" if aunitS1==2350;

 * average ITBS achievement (using prior year Spring data to match the
   way Fall attended schools are classified);
 gen tempunit=aunitS1;
 * Dyett is normally 8070, and Hope Coll Prep is normally 4130;
 replace tempunit=1600 if aunitS1==8070;
 replace tempunit=1940 if aunitS1==4130;
 if ${n}==1{; global src="e:\data\school_level\tests\"; }; 
  label drop __MERGE;
  mmerge tempunit year using "${src}itbs19972002", t(n:1) 
  unmatched(master) umatch(unit year) uif(subject=="read") 
  ukeep(subject pnorms) urename(pnorms aS1itbs);
 disp "** which AA schools are missing ITBS scores? **";
 tab aunitS1 if aunitS1>=2000 & _merge==1;
 * fill in using closest year data existing for those missing 2000 data;
 * note: have no information for 3630;
 for num 2350 5860 \ any 45.8 36.7:
  replace aS1itbs=Y if aunitS1==X & aS1itbs==. & `1'==2000;

 * replace with later data for those elem schools that recently opened;
  gen tempyr=2002;
  label drop __MERGE;
  mmerge tempunit tempyr using "${src}itbs19972002", t(n:1) 
  unmatched(master) umatch(unit year) uif(subject=="read") 
  ukeep(subject pnorms) urename(pnorms holdaS1itbs);
  disp "** which AA elem schools only have later ITBS data? **";
  tab aunitS1 if aunitS1>=2000 & aS1itbs==. & holdaS1itbs~=.;
  replace aS1itbs=holdaS1itbs if aunitS1>=2000 & aS1itbs==.;
  drop holdaS1itbs tempunit;

 * average TAPS; 
  label drop __MERGE;
  mmerge aunitS1 year using "${src}tap19912002.dta", t(n:n) 
  unmatched(master) umatch(unit year) uif(subject=="read") 
  ukeep(subject pnorms) urename(pnorms aS1tap);

 * replace with later data for those high schools that recently opened;
  label drop __MERGE;
  mmerge aunitS1 tempyr using "${src}tap19912002.dta", t(n:n) 
  unmatched(master) umatch(unit year) uif(subject=="read") 
  ukeep(pnorms subject) urename(pnorms holdaS1tap);
  disp "** which AA high schools only have later TAPS data? **";
  tab aunitS1 if aunitS1<2000 & aS1tap==. & holdaS1tap~=.;
  replace aS1tap=holdaS1tap if aunitS1<2000 & aS1tap==.;
  drop tempyr holdaS1tap;

  * combine ITBS and TAPS;
  gen aS1pnorms=aS1itbs if aunitS1>=2000&aunitS1!=.;
  replace aS1pnorms=aS1tap if aunitS1<2000&aunitS1!=.;
   label var aS1pnorms "% above reading norms";
  drop aS1itbs aS1tap subject;
 
 * selectivity;
 if ${n}==1{; global src="c:\projects\magnet schools\data\"; };
  label drop __MERGE;
  mmerge aunitS1 using "${src}schselectivity.dta", t(n:1) unmatched(master)
  umatch(unit) ukeep(mnotaa) urename(mnotaa aS1mnotaa);
   label var aS1mnotaa "% not AA students 2-year avg";

 * get tract information;
  if ${n}==0{; global src="GEOCODE\"; };
  if ${n}==1{; global src="c:\projects\magnet schools\geocode\"; };
   label drop __MERGE;
   mmerge holdunit year using "${src}pub_geo", t(n:1) unmatched(master)
    umatch(unit year) ukeep(trct00s) urename(trct00s aS1tract);
   disp "** which AA schools missing geocoded data? **";
   tab aunitS1 if _merge==1;
   * note: 5860 is missing in geocoded data, so cannot fill in;
   replace aS1tract=7001 if aunitS1==2350;
   drop holdunit;

  * Distance from home to AA school - centroid of tracts ;
  * origin=fall home tract, destination=Spring AA school tract; 
  * note: using fall home tract as origin to match how distance is defined
    for school attended in the Fall;
  if ${n}==0{; global src="GEOCODE\"; };
  if ${n}==1{; global src="e:\data\school_level\census\"; }; 
  label drop __MERGE;
  mmerge tractF1 aS1tract using "${src}tracttotractdistances", t(n:1) 
  ukeep(miles) umatch(tract_o tract_d) unmatched(master) missing(nomatch) 
  urename(miles aS1miles);
   label var aS1miles "home-assigned school distance in Spr Yr 1";
  count if tractF1~=. & aS1tract~=. & aS1miles==.;

  * Same using home location in Spring Yr 0;
  * origin=spring home tract, destination=Spring AA school tract; 
  * also fill in for those w/missing tractF1 but enrolled in CPS when apply;
  label drop __MERGE;
  mmerge tractS0 aS1tract using "${src}tracttotractdistances", t(n:1) 
  ukeep(miles) umatch(tract_o tract_d) unmatched(master) missing(nomatch)
  urename(miles aS1miles_0);
  replace aS1miles=aS1miles_0 if aS1miles==.;
    label var aS1miles_0 "Spr Yr 0 home-Spr Yr 1 assigned school dist";
  count if tractS0~=. & aS1tract~=. & aS1miles_0==.;

/*** SPRING YEAR 2 DATA TO LOOK AT IMPACTS ***/

* note: have master and transcript files for both cohorts, but 
 test data only for 2000 cohort;

** Spring Year 2 master file;

if ${n}==0{; global src=""; };
if ${n}==1{; global src="e:\fullmasterfiles\"; }; 
 label drop __MERGE;
 * note: AA unit is missing for 2nd cohort (not in Spring 2003 master file);
 if `1'==2000{; global avar="aunit5`8'"; }; 
 if `1'==2001{; global avar=""; gen aunit5`8'=.; };
 mmerge sid using "${src}allm5`8'full", t(n:1) unmatched(master) 
 ukeep(sid statu5`8' lvrea5`8' granu5`8' cursc5`8' ${avar}) 
 urename(statu5`8' statuS2 \ lvrea5`8' lvreaS2 \ granu5`8' gradeS2 \ 
 cursc5`8' curscS2);
 rename aunit5`8' aunitS2;

** high school transcript files;

if ${n}==1{; global src="e:\data\transcripts\"; }; 
 label drop __MERGE;
 mmerge sid using "${src}grspr`8'new", t(n:1) unmatched(master) 
 ukeep(sid ranksp`8' clszsp`8' gpasp`8' 
 abs1sp`8' abs2sp`8' abs3sp`8' abs4sp`8' abs5sp`8' abs6sp`8' abs7sp`8' 
 abs8sp`8' abs9sp`8' abs0sp`8'
 crd1sp`8' crd2sp`8' crd3sp`8' crd4sp`8' crd5sp`8' crd6sp`8' crd7sp`8' 
 crd8sp`8' crd9sp`8' crd0sp`8'
 fmk1sp`8' fmk2sp`8' fmk3sp`8' fmk4sp`8' fmk5sp`8' fmk6sp`8' fmk7sp`8' 
 fmk8sp`8' fmk9sp`8' fmk0sp`8');
	
 rename gpasp`8' gpaS2;
 egen mabsS2=rmean(abs1sp`8' abs2sp`8' abs3sp`8' abs4sp`8' abs5sp`8' 
      abs6sp`8' abs7sp`8' abs8sp`8' abs9sp`8' abs0sp`8');
 egen tcrdS2=rsum(crd1sp`8' crd2sp`8' crd3sp`8' crd4sp`8' crd5sp`8' 
      crd6sp`8' crd7sp`8' crd8sp`8' crd9sp`8' crd0sp`8');
  gen temp=0;
  for num 1/9 0: replace temp=1 if crdXsp`8'~=.;
  replace tcrdS2=. if temp==0;
  drop temp;
 egen anyfS2=rany(fmk1sp`8' fmk2sp`8' fmk3sp`8' fmk4sp`8' fmk5sp`8' 
      fmk6sp`8' fmk7sp`8' fmk8sp`8' fmk9sp`8' fmk0sp`8'), c(@=="F");
 egen numfS2=rcount(fmk1sp`8' fmk2sp`8' fmk3sp`8' fmk4sp`8' fmk5sp`8' 
      fmk6sp`8' fmk7sp`8' fmk8sp`8' fmk9sp`8' fmk0sp`8'), c(@=="F");
  gen temp=0;
  for num 1/9 0: replace temp=1 if fmkXsp`8'~="";
  for var anyfS2 numfS2: replace X=. if temp==0;
  drop temp;
 gen crankS2=round((ranksp`8'/clszsp`8')*100,.1);
 drop ranksp`8' clszsp`8' abs* crd* fmk*;

 label var gpaS2 "Cumulative GPA Spr Yr 2";
 label var mabsS2 "Average course absences Spr Yr 2";
 label var tcrdS2 "Total credits earned Spr Yr 2";
 label var anyfS2 "At least 1 F Spr Yr 2";
 label var numfS2 "Total # of Fs Spr Yr 2";
 label var crankS2 "Class rank Spr Yr 2";

if `1'==2000{;

** ITBS & TAP data ;

if ${n}==1{; global src="e:\data\itbs\"; }; 
 label drop __MERGE;
 mmerge sid using "${src}itbs`7'b", t(n:1) unmatched(master) 
 ukeep(sid readxil mathtxil) urename(readxil irdxilS2 \ mathtxil imtxilS2);

if ${n}==1{; global src="e:\data\tap\"; }; 
  label drop __MERGE;
  mmerge sid using "${src}tap`7'b", t(n:1) unmatched(master) 
  ukeep(sid readxil readge) urename(readxil trdxilS2 \ readge trdgeS2);

** Spring Year 2 Case Exam Files;

 * note: only pulling exams that are most commonly taken in Spring Year 2
 (10th grade).  These are history, geometry, and English 2;
 if ${n}==0{; global src="CASE_EXAMS\"; };
 if ${n}==1{; global src="c:\projects\magnet schools\case_exams\"; }; 
  label drop __MERGE;
 mmerge sid using "${src}case`7's", t(n:1) unmatched(master) 
 ukeep(cs_geo_mpct cs_geo_cpct cs_geo_tpct
 cs_eng2_mpct cs_eng2_cpct cs_eng2_tpct cs_his_mpct cs_his_cpct cs_his_tpct);
 for any geo eng2 his: rename cs_X_mpct XmpS2 \
 rename cs_X_cpct XcpS2 \ rename cs_X_tpct XtpS2 \ 
 replace XmpS2=XmpS2/100 \ replace XcpS2=XcpS2/100 \ replace XtpS2=XtpS2/100; 
};

/*** SPRING YEAR 3 DATA TO LOOK AT IMPACTS ***/

** Spring Year 3 master file;

if ${n}==0{; global src=""; };
if ${n}==1{; global src="e:\fullmasterfiles\"; }; 
 label drop __MERGE;
 * note: no AA unit in Spring 2003 file or Spring 2004 file;
 mmerge sid using "${src}allm5`10'full", t(n:1) unmatched(master) 
  ukeep(sid statu5`10' lvrea5`10' lvexp5`10' granu5`10' cursc5`10')
  urename(statu5`10' statuS3 \ lvrea5`10' lvreaS3 \ lvexp5`10' lvexpS3 \
  granu5`10' gradeS3 \ cursc5`10' curscS3);
 label var lvreaS3 "code for reason left Spr Yr 3";
 label var lvexpS3 "explanation for reason left Spr Yr 3";

/*** SPRING YEAR 4 AND FALL YEAR 5 DATA TO LOOK AT IMPACTS ***/

if `1'==2000{;

if ${n}==1{; global src="e:\fullmasterfiles\"; }; 
 label drop __MERGE;
 * note: no AA unit in Spring 2004;
 mmerge sid using "${src}allm5`12'full", t(n:1) unmatched(master) 
  ukeep(sid statu5`12' lvrea5`12' granu5`12' cursc5`12')
  urename(statu5`12' statuS4 \ lvrea5`12' lvreaS4 \ granu5`12' gradeS4 \ 
  cursc5`12' curscS4);

 label drop __MERGE;
 * note: use following September data to get the correct graduation data 
   for those in the 2000 cohort who managed to graduate in 4 yrs;
 mmerge sid using "${src}allm9`12'full", t(n:1) unmatched(master) 
  ukeep(sid statu9`12' lvrea9`12' lvexp9`12' granu9`12')
  urename(statu9`12' statuF5 \ lvrea9`12' lvreaF5 \ 
   lvexp9`12' lvexpF5 \ granu9`12' gradeF5); 
 label var lvreaF5 "code for reason left Fall Yr 5";
 label var lvexpF5 "explanation for reason left Fall Yr 5";

};

** Merge in data from leave-log files. Apparently, CPS uses these to
 verify dropouts and they are supposedly more reliable than the lvrea 
 codes in masterfile;

if ${n}==1{; global src="e:\fullmasterfiles\"; }; 
 label drop __MERGE;
 mmerge sid using "${src}leavelog0304", t(n:1) unmatched(master) 
  ukeep(sid dropunit drpgrade dropcode leaved lvcode);


**********************;
***CREATE VARIABLES***;
**********************;

***STUDENT DEMOGRAPHICS***;

** Student demographics from CPS masterfiles and application files;
* we use the demographic information available on the application files for
  the variables available there, and then otherwise use variables defined
  for those those enrolled in Spring Year 0;
* later in the program, we try to use data from Fall Year 1 and Spring Year
  1 to fill in these background variables for students who were not enrolled
  in Spring Year 0 but subsequently show up in CPS;

** enrollment status;
 tab statuS0;
 gen enrollS0=statuS0==1|statuS0==2;
  label var enrollS0 "enrolled in CPS in Spr Yr 0";
 tab enrollS0;
 drop statuS0;

 tab uS0name if uS0type=="";
 replace uS0type="PreKdg" if (uS0name=="VICK EARLY CHILD CTR"|
  uS0name=="CRADLE TO CLASSROOM"|uS0name=="STATE PREKDGN PROG") & uS0type=="";
 replace uS0type="Alternative" if uS0nam=="SPECIALIZED/ALT SCHL" & uS0type=="";
 tab unitS0 if uS0name=="" & unitS0~=.;
 replace uS0name="COLEMAN, J" if uS0name=="" & unitS0==6170;
 tab unitS0 if uS0type=="" & unitS0~=.;
 replace uS0type="General" if uS0type=="" & unitS0==6170;

 * express all school characteristics as fractions of the whole;
 summ uS0*;
 for var uS0p* uS0itbs: replace X=X/100;
 * convert unit numbers to be main unit numbers;
 for var aunitS0 aaunit hunit: replace X=int(X/10)*10;

 * Note: hunit in applications data seems pretty noisy;
 gen nomatch=(hunit~=unitS0) if hunit~=. & unitS0~=.;
 disp "** How often do hunit & unitS0 not match if enrolled Spr Yr 0? **";
 summ nomatch;
 disp "** When do not match, how often is hunit equal to choice unit? **";
 gen repchoice=(hunit==cunit) if hunit~=. & cunit~=.;
 summ repchoice if nomatch==1;
 drop nomatch repchoice;

 * many cases where hunit exists even if student wasn't enrolled that Spring; 
 * it could be that hunit refers to the last CPS school the student attended
   or are reporting choice school;
 disp "** Cases where hunit exists and student not enrolled **";
 count if unitS0==. & hunit~=.;
 gen temp1=(unitS0==.&hunit~=.);
 egen temp2=sum(temp1), by(hunit);
 egen temp3=sum(temp1);
 replace temp3=temp2/temp3;
 * Note: these are all magnets, except 8880 and 9990 which are not valid #'s;
 disp "** Which hunits often reported by students not enrolled in CPS? **";
 tab hunit if temp3>.05;
 drop temp* hunit;

** indicator for whether attending assigned school;
 * note: some are missing attendance area unit number;
 count if aunitS0==. & enrollS0==1;
 summ aunitS0, detail;
 replace aunitS0=. if aunitS0==0;
 * Note: aaunit in applications data seems noisy;
 disp "** How often do aaunit & aunitS0 not match if enrolled Spr Yr 0? **";
 gen nomatch=(aunitS0~=aaunit) if aunitS0~=. & aaunit~=.;
 summ nomatch;
 * fill in using aaunit if aunitS0 is missing;
 replace aunitS0=aaunit if aunitS0==. & enrollS0==1;
 drop nomatch aaunit;
  label var aunitS0 "attendance area unit Spr Yr 0";
 gen byte yyaa=(aunitS0==unitS0) if aunitS0~=. & unitS0~=.;
 summ yyaa;
  label var yyaa "attending AA sch Spr Yr 0";
 drop aunitS0;

** grade-level;
 tab gradeS0;
 * Note: 20s=self-contained spec ed, 30s=head start, 40s=kindergarten,
   50's=special ed kindergarten, 60s=pre-school, 70s=bilingual pre-sch,
   80's=state-funded pre-K, 90s=special ed for ages 3-5;
  label var gradeS0 "grade assignment in Spr Yr 0";

 * compare to grade reported on application file;
 * Note: on application file, PS & 40=pre-schooler applying for kindergarten, 
   KG=kindergartner applying to 1st (for Disney Magnet: 30=applicant for 3-yr
   old pre-K program, 40=applicant for 4-yr old pre-K program, PS=applicant
   for kindergarten);
 
 * below -1=pre-K , 0=KG , 1-12, 13=special ed;
 gen gr_cps=gradeS0;
 replace gr_cps=-1 if (gr_cps>=30 & gr_cps<40)|(gr_cps>=60 & gr_cps~=.);
 replace gr_cps=0 if gr_cps>=40 & gr_cps<60;
 replace gr_cps=13 if gr_cps>=20 & gr_cps<30;
 gen gr_app=real(gr);
 replace gr_app=-1 if gr=="PS"|gr=="30"|gr=="40";
 replace gr_app=0 if gr=="KG";
 disp "** how do CPS and application current grades compare? **";
 tab gr_cps gr_app if gr_cps<3 & gr_app<4, row;
 tab gr_cps gr_app if gr_cps>=3 & gr_cps<7 & gr_app>=3 & gr_app<8, row;
 tab gr_cps gr_app if gr_cps>=7 & gr_cps<10 & gr_app>=7 & gr_app<11, row;
 tab gr_cps gr_app if gr_cps>=10 & gr_cps<=12 & gr_app>=9, row;
 tab gr_app if gr_cps==13;
 drop gr_cps gr_app;

 * Note: for early grades, reported grade is often not current grade but
   grade to which applying. In later grades, often see applications grade
   listed as grade earlier than grade enrolled in.  This is due to the fact
   that schools use the "gr" entry to group students for lotteries, and
   lotteries are often run jointly for students across a set of grades;

** family status;
 tab guardS0;
 * note: 1=dad 2=mom 3=stepdad 4=stepmom 5=g-pa 6=g-ma 7=othr rel 8=no rel
         U=uncle A=aunt B=brother S=sister C=cousin P=?;
 gen byte yypar=guardS0=="1"|guardS0=="2" if guardS0~="";
  label var yypar "guardian is bio mom or dad";
 drop guardS0;

** free/reduced price lunch;
 tab lunchS0;
 gen byte yyflunch=lunchS0=="F" if enrollS0==1;
 gen byte yyrlunch=lunchS0=="R" if enrollS0==1;
  label var yyflunch "elig for free lunch Spr Yr 0";
  label var yyrlunch "elig for reduced lunch Spr Yr 0";
 drop lunchS0;

** special ed status;
 tab spedS0;
 gen byte yysped=spedS0!="" if enrollS0==1;
  label var yysped "in spec ed Spr Yr 0";
 drop spedS0;

** bilingual category;
 tab bcatS0;
 if `1'==2001{;
 gen temp=real(bcatS0);
 drop bcatS0;
 rename temp bcatS0;
 };
 gen byte yybil=(bcatS0>=1&bcatS0<=4) if enrollS0==1;
  label var yybil "in bil ed now or ever Spr Yr 0";
 drop bcatS0;

** race/ethnicity;
 tab ethniS0, miss;
 tab rc, miss;
 for any whi blk natam asian hisp \ num 1/5: gen byte X=ethniS0==Y if
     ethniS0~=. \ gen byte xxX=(rc==Y) if rc~=.;
 gen nomatch_race=(xxwhi~=whi|xxblk~=blk|xxnata~=nata|xxasian~=asian|
   xxhisp~=hisp) if ethniS0~=. & rc~=.;
 disp "** How often do CPS race and application report not match? **";
 summ nomatch_race;
 tabstat badmatch, by(nomatch_race);
 drop ethniS0 blk whi natam asian hisp;
  label var xxwhi "white";
  label var xxblk "black";
  label var xxnatam "native american";
  label var xxasian "asian";
  label var xxhisp "hispanic";
  
** gender;
 tab gendS0, miss;
 tab sx, miss;
 gen male=gendS0==1 if gendS0~=.;
 gen xxmale=sx=="M" if sx~="";
 gen nomatch_sex=(xxmale~=male) if xxmale~=. & male~=.;
 disp "** How often do CPS sex and application report not match? **";
 summ nomatch_sex;
 tabstat badmatch, by(nomatch_sex);
  label var xxmale "male";
 drop male gendS0;

** age (on Jan.1 of application year);
 * note: bdateS0 is "MMDDYY";
 summ bdateS0;
 gen str6 tmpvar=string(bdateS0);
 replace tmpvar="0"+substr(tmpvar,1,5) if bdateS0<100000;
 gen str8 tmpvar2=substr(tmpvar,1,2)+"/"+substr(tmpvar,3,2)+"/"+
     substr(tmpvar,5,2);
 gen tmpbdate=date(tmpvar2,"md19y") if tmpvar2~="";
 gen tmp=mdy(1,1,`1');
 gen age=round(((tmp-tmpbdate)/365),.1);
 sum age, detail;
 list bdateS0 bdate if age>90 & age~=.;
 drop tmp*;

 summ bdate;
 * note: bdate is "YYMMDD";
 * fix typos:
 summ bdate, detail;
 list idseq sid bdate bdateS0 if bdate<100000;
 replace bdate=930414 if bdate==93414;
 replace bdate=881124 if bdate==1124 & bdateS0==112488;
 replace bdate=920912 if bdate==912 & bdateS0==91292;
 replace bdate=870113 if bdate==113 & bdateS0==11387;
 replace bdate=. if bdate<100000;
 gen str6 tmpvar=string(bdate);
 gen str8 tmpvar2=substr(tmpvar,3,2)+"/"+substr(tmpvar,5,2)+"/"+
     substr(tmpvar,1,2);
 gen tmpbdate=date(tmpvar2,"md19y") if tmpvar2~="";
 gen tmp=mdy(1,1,`1');
 gen xxage=round(((tmp-tmpbdate)/365),.1);
 sum xxage, detail;
 disp "** birth dates where age 0 is assigned **";
 list xxage bdate if xxage==0;
 disp "** birth dates where age 19+ is assigned **";
 list xxage bdate if xxage>=19 & xxage~=.;
 drop tmp*;

 gen nomatch_age=(xxage~=age) if age~=. & xxage~=.;
 disp "** How often does CPS age not match age reported on application? **";
 summ nomatch_age;
 tabstat badmatch, by(nomatch_age);
 drop age;

 * set to mean by grade if missing;
 disp "** show observations with missing age information **";
 list bdate* gr enrollS0 statuF1 if xxage==.;
 egen temp=mean(xxage), by(cunit gr);
 replace xxage=temp if xxage==.;
 drop temp bdateS0 bdate;
  label var xxage "age as of Jan. 1 Spr Yr 0";

 * create combined indicator for mis-matches between applications and
 master file demographic data;
 gen temp=max(nomatch_race,nomatch_sex,nomatch_age);
 egen baddemog=max(temp), by(idseq);
 summ baddemog;
 tab badmatch if baddemog==1;
  label var baddemog "birthday/race/or sex differs in appl and master file";
 drop nomatch* temp;

** test scores (defined for grades 1-12);
 * note: only 41% of 1st-graders and 32% of 2nd-graders take the ITBS;
 summ irdxilS0 imtxilS0 trdxilS0;
 disp "** which grades take ITBS? **";
 tab gradeS0 if (irdxilS0~=.|imtxilS0~=.);
 disp "** which grades take TAP? **";
 tab gradeS0 if trdxilS0~=.;  
 gen rdxilS0=irdxilS0 if enrollS0==1&gradeS0>=1&gradeS0<=8;
 replace rdxilS0=trdxilS0 if enrollS0==1&gradeS0>=9&gradeS0<=12;
 gen mtxilS0=imtxilS0 if enrollS0==1&gradeS0>=1&gradeS0<=8;
 for var rdxilS0 mtxilS0: replace X=X/100;
 gen rdgeS0=trdgeS0 if enrollS0==1&gradeS0>=9&gradeS0<=12;
  label var rdxilS0 "reading ITBS/TAP percentile";
  label var mtxilS0 "math ITBS percentile";
  label var rdgeS0 "reading TAP grade equiv";
 summ rdxilS0 mtxilS0 rdgeS0;
 drop irdxilS0 imtxilS0 trdxilS0 trdgeS0;

** check to make sure defined for appropriate observations;
 summ xx* yy* rdxilS0 mtxilS0;
 gen zmiss=(rdxilS0==.) if enrollS0==1;
 summ zmiss;
 gen temp=gradeS0;
 replace temp=. if temp>12 & temp~=.;
 * rates of missing test scores by grade;
 disp "** What fraction have missing reading test scores by grade? **";
 tabstat zmiss, by(temp);
 drop temp zmiss;
 
** adjust test scores from Spring prior to application;
 for any rdxil_1 mtxil_1: rename iX X \ replace X=X/100;
  label var rdxil_1 "reading ITBS pctile gr b/f appl";
  label var mtxil_1 "math ITBS pctile gr b/f appl";

** check choice school variables;
 for var cuname cutype: tab cunit if X=="";
 summ cu*;
 for var cupwhi cupblk cuphisp cuplep cuploinc cupattnd cupdrop cupgrad
  cupnorms: replace X=X/100;
 
***FALL AND SPRING ENROLLMENT VARIABLES YEAR 1***;

** basic status variables;

 * Fall Yr 1; 
 tab statuF1, miss;
 gen enrollF1=statuF1==1|statuF1==2;
 tab enrollF1;
  label var enrollF1 "enrolled in CPS in Fall Yr 1";
 summ unitF1 gradeF1;
  label var unitF1 "unit enrolled in Fall Yr 1";
  label var gradeF1 "grade in Fall Yr 1";
 drop statuF1;

 gen insch=(cunit==unitF1&enrollF1==1);
 egen dinsch=max(insch), by(idseq);
 summ insch dinsch;
  label var insch "enr in this appl sch Fall Yr 1";
  label var dinsch "enr in any appl sch Fall Yr 1";

 count if enrollF1==1 & unitF1==.;
 count if enrollF1==1 & uF1name=="";
 tab uF1name if uF1type=="" & enrollF1==1;
 replace uF1type="PreKdg" if (uF1name=="CRADLE TO CLASSROOM"|
  uF1name=="STATE PREKDGN PROG") & uF1type=="";
 replace uF1type="Alternative" if uF1name=="SPECIALIZED/ALT SCHL" 
  & uF1type=="";
 replace uF1type="Special Education" if uF1name=="SP ED DUAL ENROLL"
  & uF1type=="";
 * note: Chicago Academy and Davis/Shields are new schools;
 replace uF1type="General" if (uF1name=="CHICAGO ACADEMY"|
  uF1name=="DAVIS/SHIELDS"|uF1name=="DYETT MIDDLE"|uF1name=="COLEMAN, J")
  & uF1type==""; 

 * express all school characteristics as fractions of the whole;
 summ uF1*;
 for var uF1pwhi uF1pblk uF1phisp uF1plep uF1ploinc uF1pattnd
  uF1pdrop uF1pgrad uF1pnorms: replace X=X/100;
 
 * Spring yr 1;
 rename curscS1 unitS1;
 for var unitS1: replace X=int(X/10)*10;
 tab statuS1, miss;
 * check to see if there are any early graduates-- 
  might confuse issue of whether enrolled or not;
 count if lvreaF1==45|lvreaS1==45;
 gen enrollS1=statuS1==1|statuS1==2;
 tab enrollS1 enrollF1, row;
 tab lvreaF1 if enrollF1==0 & enrollS1==1;
 summ unitS1 gradeS1;
  label var enrollS1 "enrolled in Spr Yr 1";
  label var unitS1 "unit enrolled in Spr Yr 1";
  label var gradeS1 "grade in Spr Yr 1";
 drop statuS1;

 * indicator for whether attending assigned school;
 summ aunitS1;
 * note: already converted to main unit number above;
 gen byte aaS1=(aunitS1==unitS1) if aunitS1~=. & unitS1~=. & enrollS1==1;
 summ aaS1;
  label var aaS1 "attending AA school in Spr Yr 1";

 summ aS1*;
 replace aS1pnorms=aS1pnorms/100;

 * Spring yr 2;
 rename curscS2 unitS2;
 for var unitS2 aunitS2: replace X=int(X/10)*10;
 tab statuS2, miss;
 count if lvreaS2==45;
 gen enrollS2=statuS2==1|statuS2==2;
 tab enrollS2 enrollS1, row;
 summ unitS2 gradeS2;
 gen temp=(unitS1==unitS2) if unitS1~=. & enrollS2==0;
 summ temp;
 for var unitS2 gradeS2: replace X=. if enrollS2==0;
  label var enrollS2 "enr in CPS in Spr Yr 2";
  label var unitS2 "unit enrolled in Spr Yr 2";
  label var gradeS2 "grade in Spr Yr 2";
 drop temp statuS2;
 
 * indicator for whether attending assigned school;
 summ aunitS2;
 replace aunitS2=. if aunitS2==0|enrollS2==0;
 gen byte aaS2=(aunitS2==unitS2) if aunitS2~=. & unitS2~=. & enrollS2==1;
 summ aaS2;
  label var aaS2 "attending AA school in Spr Yr 2";
 drop aunitS2;

 * Spring yr 3;
 rename curscS3 unitS3;
 for var unitS3: replace X=int(X/10)*10;
 tab statuS3, miss;
 count if lvreaS3==45;
 gen enrollS3=statuS3==1|statuS3==2;
 tab enrollS3 enrollS2, row;
 summ unitS3 gradeS3;
 for var unitS3 gradeS3: replace X=. if enrollS3==0;
  label var enrollS3 "enr in CPS in Spr Yr 3";
  label var unitS3 "unit enrolled in Spr Yr 3";
  label var gradeS3 "grade in Spr Yr 3";
 drop statuS3;

 * Spring yr 4 and and Fall yr 5;
 if `1'==2000{;
 rename curscS4 unitS4;
 for var unitS4: replace X=int(X/10)*10;
 tab statuS4, miss;
 count if lvreaS4==45;
 * note: our definition does not count early graduates as enrolled; 
 tab gradeS3 gradeS4 if lvreaS4==45, m row;
 gen enrollS4=(statuS4==1|statuS4==2);
 tab enrollS4 enrollS3, row;
 summ unitS4 gradeS4;
 for var unitS4 gradeS4: replace X=. if enrollS4==0;
  label var enrollS4 "enr in CPS in Spr Yr 4";
  label var unitS4 "unit enrolled in Spr Yr 4";
  label var gradeS4 "grade in Spr Yr 4";
 drop statuS4;

 tab statuF5, miss;
 gen enrollF5=(statuF5==1|statuF5==2);
 replace gradeF5=. if enrollF5==0;
  label var enrollF5 "enr in CPS in Fall Yr 5";
  label var gradeF5 "grade in Fall Yr 5";
 drop statuF5; 
 };

** fill in demographics for those not in system in Spr Yr 0 using Yr 1
   Fall and Spring master files;

* family status (F1);
 tab guardF1 if enrollF1==1, miss;
 tab guardS1 if enrollS1==1, miss;
 gen par=(guardF1=="1"|guardF1=="2") if guardF1~="";
 replace par=(guardS1=="1"|guardS1=="2") if guardS1~="" & par==.;
 gen nomatch=(par~=yypar) if par~=. & yypar~=.;
 disp "** How often does guardian in F1/S1 not match guardian in S0? **";
 summ nomatch;
 tabstat badmatch, by(nomatch);
 count if yypar==. & enrollS0==1;
 replace yypar=par if yypar==.;
 gen temp=1 if enrollS0==1|enrollF1==1|enrollS1==1;
 count if temp==1;
 summ yypar;
 drop par guardF1 guardS1 nomatch temp;

* special ed status (F1);
 tab spedF1;
 gen sped=spedF1~="" if enrollF1==1;
 gen tempS1=spedS1~="" if enrollS1==1;
 disp "** how stable is special ed classification from F1 to S1? **";
 tab sped tempS1, cell;
 tab sped tempS1 if enrollS0==8, cell;
 replace sped=tempS1 if sped==.; 
 disp "** How often does sped status in F1/S1 not match status in S0? **";
 gen nomatch=(yysped~=sped) if yysped~=. & sped~=.;
 summ nomatch;
 tabstat badmatch, by(nomatch);
 count if yysped==. & enrollS0==1;
 replace yysped=sped if yysped==.;
 summ yysped;
 drop sped spedF1 spedS1 nomatch tempS1;

* free/reduced price lunch (S1);
 tab lunchS1;
 gen byte flunch=(lunchS1=="F") if enrollS1==1;
 gen byte rlunch=(lunchS1=="R") if enrollS1==1;
 gen nomatchf=(yyflunch~=flunch) if yyflunch~=. & flunch~=.;
 gen nomatchr=(yyrlunch~=rlunch) if yyrlunch~=. & rlunch~=.;
 disp "** How often does lunch status in S1 not match status in S0? **";
 summ nomatch*;
 count if yyflunch==. & enrollS0==1;
 replace yyflunch=flunch if yyflunch==.;
 replace yyrlunch=rlunch if yyrlunch==.;
 summ yyflunch yyrlunch;
 drop flunch rlunch lunchS1 nomatch*;

** bilingual category (S1);
 tab bcatS1;
 gen temp=real(bcatS1);
 gen byte bil=(temp>=1&temp<=4) if enrollS1==1;
 gen nomatch=(yybil~=bil) if yybil~=. & bil~=.;
 disp "** How often does bilingual status in S1 not match S0? **";
 summ nomatch;
 count if yybil==. & enrollS0==1;
 replace yybil=bil if yybil==.;
 drop bcatS1 bil temp nomatch;

***OUTCOME VARIABLES***; 

*** Spring Year 1;

* reasons left the system for those enrolled in Spr Yr 0 who did not
  show up in Fall Yr 1;
* the administrative files are updated over time, so we replace the
 leave code with the most recent leave code available if the student
 continues to not be enrolled;
 disp "** reasons why students left by Fall Yr 1 **";
 replace lvreaF1=lvreaS1 if enrollF1==0 & enrollS1==0 & 
  lvreaS1~=0 & lvreaS1~=.;
 replace lvreaF1=lvreaS2 if enrollF1==0 & enrollS1==0 & enrollS2==0 & 
  lvreaS2~=0 & lvreaS2~=.;
 replace lvreaF1=lvreaS3 if enrollF1==0 & enrollS1==0 & enrollS2==0 & 
  enrollS3==0 & lvreaS3~=0 & lvreaS3~=.;
 capture replace lvreaF1=lvreaS4 if enrollF1==0 & enrollS1==0 & 
  enrollS2==0 & enrollS3==0 & enrollS4==0 & lvreaS4~=0 & lvreaS4~=.;
 capture replace lvreaF1=lvreaF5 if enrollF1==0 & enrollS1==0 & 
  enrollS2==0 & enrollS3==0 & enrollS4==0 & enrollF5==0 
  & lvreaF5~=0 & lvreaF5~=.;

 tab lvreaF1 if enrollS0==1 & enrollF1==0, miss;
 for any dropF1 privF1 leftF1: gen X=0 if enrollS0==1; 
 replace dropF1=(lvreaF1>=34&lvreaF1<=66&lvreaF1~=45) if enrollS0==1 
  & enrollF1==0;
 replace privF1=(lvreaF1==32) if enrollS0==1 & enrollF1==0;
 replace leftF1=(lvreaF1==33) if enrollS0==1 & enrollF1==0;
 count if enrollS0==1;
 summ dropF1 privF1 leftF1;
  label var dropF1 "dropped out of school";
  label var privF1 "left CPS for Chicago non-public school";
  label var leftF1 "transfer to sch out of Chicago";

* Dropout/transfer;  
 disp "** reasons why students left by Spring Yr 1 **";
 replace lvreaS1=lvreaS2 if enrollS1==0 & enrollS2==0 & 
  lvreaS2~=0 & lvreaS2~=.;
 replace lvreaS1=lvreaS3 if enrollS1==0 & enrollS2==0 & enrollS3==0 
  & lvreaS3~=0 & lvreaS3~=.;
 capture replace lvreaS1=lvreaS4 if enrollS1==0 & enrollS2==0 
  & enrollS3==0 & enrollS4==0 & lvreaS4~=0 & lvreaS4~=.;
 capture replace lvreaS1=lvreaF5 if enrollS1==0 & enrollS2==0 
  & enrollS3==0 & enrollS4==0 & enrollF5==0 & lvreaF5~=0 & lvreaF5~=.;
 tab lvreaS1 if enrollF1==1 & enrollS1==0, miss;
 gen dropS1=enrollS1==0&lvreaS1>=34&lvreaS1<=66&lvreaS1~=45 if enrollF1==1;
 gen privS1=enrollS1==0&lvreaS1==32 if enrollF1==1;
 gen leftS1=enrollS1==0&lvreaS1==33 if enrollF1==1; 
 for any drop priv left: replace XS1=XF1 if enrollF1==0 & enrollS1==0 \
  replace XS1=0 if enrollF1==0 & enrollS1==1;
 count if enrollS0==1|enrollF1==1|enrollS1==1;
 summ dropS1 privS1 leftS1;
  label var dropS1 "dropped out Spr of Yr 1 (enr Fall Yr 1)";
  label var privS1 "transfer to priv sch Spr Yr 1 (enr Fall Yr 1)";
  label var leftS1 "transfer to sch out of Chic Spr Yr 1 (enr Fall Yr 1)";

* High school absences, credits and grades;
 tab gradeS1 enrollS1 if gpaS1~=., miss;
 for any gpa mabs tcrd anyf numf crank: replace XS1=. if 
  (enrollS1==0|gradeS1<9|gradeS1>12);
 disp "** how many enrolled in 9-12 in Spr Yr 1? **";
 count if enrollS1==1 & gradeS1>=9 & gradeS1<=12;
 summ mabsS1 tcrdS1 anyfS1 numfS1 gpaS1 crankS1;

* Standardized test scores;
 gen rdxilS1=irdxilS1 if enrollS1==1&gradeS1>=1&gradeS1<=8;
 replace rdxilS1=trdxilS1 if enrollS1==1&gradeS1>=9&gradeS1<=12;
 gen mtxilS1=imtxilS1 if enrollS1==1&gradeS1>=1&gradeS1<=8;
 gen rdgeS1=trdgeS1 if enrollS1==1&gradeS1>=9&gradeS1<=12;
 drop irdxilS1 trdxilS1 imtxilS1 trdgeS1;
 for var rdxilS1 mtxilS1: replace X=X/100;
  label var rdxilS1 "reading ITBS/TAP percentile";
  label var mtxilS1 "math ITBS percentile";
  label var rdgeS1 "reading TAP grade equiv";
 summ rdxilS1 mtxilS1 rdgeS1;

* Case exams;
 for any bio wld alg eng1: 
 replace XmpS1=. if enrollS1==0|gradeS1<9|gradeS1>12 \
 replace XcpS1=. if enrollS1==0|gradeS1<9|gradeS1>12 \
 replace XtpS1=. if enrollS1==0|gradeS1<9|gradeS1>12;

*** Spring Year 2;

* Dropout/transfer;  
 disp "** reasons why students left by Spring Yr 2 **";
 replace lvreaS2=lvreaS3 if enrollS2==0 & enrollS3==0 & 
  lvreaS3~=0 & lvreaS3~=.;
 capture replace lvreaS2=lvreaS4 if enrollS2==0 & enrollS3==0 & 
  enrollS4==0 & lvreaS4~=0 & lvreaS4~=.;
 capture replace lvreaS2=lvreaF5 if enrollS2==0 & enrollS3==0 & 
  enrollS4==0 & enrollF5==0 & lvreaF5~=0 & lvreaF5~=.;
 tab lvreaS2 if enrollS1==1 & enrollS2==0, miss;
 gen dropS2=enrollS2==0&lvreaS2>=34&lvreaS2<=66&lvreaS2~=45 if enrollS1==1;
 gen privS2=enrollS2==0&lvreaS2==32 if enrollS1==1;
 gen leftS2=enrollS2==0&lvreaS2==33 if enrollS1==1;
 for any drop priv left: 
  replace XS2=XS1 if enrollS1==0 & enrollS2==0 \ 
  replace XS2=0 if enrollS1==0 & enrollS2==1;
 count if enrollS0==1|enrollF1==1|enrollS1==1|enrollS2==1;
 summ dropS2 privS2 leftS2;
  label var dropS2 "dropped out by Spr of Yr 2";
  label var privS2 "transfer to priv sch by Spr Yr 2";
  label var leftS2 "transfer to sch out of Chic by Spr Yr 2";

* High school absences, credits and grades;
 for any gpa mabs tcrd anyf numf crank: 
  replace XS2=. if (enrollS2==0|gradeS2<9|gradeS2>12);
 disp "** how many enrolled in 9-12 in Spr Yr 2? **";
 count if enrollS2==1 & gradeS2>=9 & gradeS2<=12;
 summ mabsS2 tcrdS2 anyfS2 numfS2 gpaS2 crankS2;

if `1'==2000{;

* Standardized test scores;
 gen rdxilS2=irdxilS2 if enrollS2==1&gradeS2>=1&gradeS2<=8;
 replace rdxilS2=trdxilS2 if enrollS2==1&gradeS2>=9&gradeS2<=12;
 gen mtxilS2=imtxilS2 if enrollS2==1&gradeS2>=1&gradeS2<=8;
 gen rdgeS2=trdgeS2 if enrollS2==1&gradeS2>=9&enrollS2<=12;
 drop irdxilS2 trdxilS2 imtxilS2 trdgeS2;
 for var rdxilS2 mtxilS2: replace X=X/100;
 summ rdxilS2 mtxilS2 rdgeS2;
  label var rdxilS2 "reading ITBS/TAP percentile";
  label var mtxilS2 "math ITBS percentile";
  label var rdgeS2 "reading TAP grade equiv";

* Case exams;
 for any his geo eng2: 
 replace XmpS2=. if enrollS2==0|gradeS2<9|gradeS2>12 \
 replace XcpS2=. if enrollS2==0|gradeS2<9|gradeS2>12 \
 replace XtpS2=. if enrollS2==0|gradeS2<9|gradeS2>12;
};

*** Spring Year 3 ;

* Dropout/transfer/jail;  
disp "** reasons why students left by Spring Yr 3 **";
 capture replace lvreaS3=lvreaS4 if enrollS3==0 & enrollS4==0 & 
  lvreaS4~=0 & lvreaS4~=.;
 capture replace lvreaS3=lvreaF5 if enrollS3==0 & enrollS4==0 & 
  enrollF5==0 & lvreaF5~=0 & lvreaF5~=.;
 tab lvreaS3 if enrollS2==1 & enrollS3==0, miss;
 gen dropS3=enrollS3==0&lvreaS3>=34&lvreaS3<=66&lvreaS3~=45 if enrollS2==1;
 gen privS3=enrollS3==0&lvreaS3==32 if enrollS2==1;
 gen leftS3=enrollS3==0&lvreaS3==33 if enrollS2==1;
 for any drop priv left: 
  replace XS3=XS2 if enrollS2==0 & enrollS3==0 \ 
  replace XS3=0 if enrollS2==0 & enrollS3==1;
 count if enrollS0==1|enrollF1==1|enrollS1==1|enrollS2==1|enrollS3==1;
 summ dropS3 leftS3 privS3;
  label var dropS3 "dropped out by Spr of Yr 3";
  label var privS3 "transfer to Chic priv sch by Spr Yr 3";
  label var leftS3 "transfer to sch out of Chic by Spr Yr 3";

 * add subcategories included within dropping out;
 gen dieS3=dropS3==1&lvreaS3==41 if dropS3~=.;
 gen pregS3=dropS3==1&lvreaS3==44 if dropS3~=.;
 gen jailS3=dropS3==1&lvreaS3==35 if dropS3~=.;
  label var dieS3 "drop out b/c dead by Spr Yr 3";
  label var pregS3 "drop out b/c pregnant by Spr Yr 3";
  label var jailS3 "drop out b/c in jail by Spr Yr 3";

 * Compare to July leavelog data file (corrects/updates May file);
 if `1'==2001{;
  for var dropS3 privS3 leftS3: tab lvreaS3 dropcode if enrollS3==0&X==1, m;
 };

*** Spring Year 4 and Fall Year 5;

if `1'==2000{;

* Dropout/transfer;
disp "** reasons why students left by Spring Yr 4 **";
 replace lvreaS4=lvreaF5 if enrollS4==0 & enrollF5==0 & 
  lvreaF5~=0 & lvreaF5~=.;
 tab lvreaS4 if enrollS3==1 & enrollS4==0, miss;
 gen dropS4=enrollS4==0&lvreaS4>=34&lvreaS4<=66&lvreaS4~=45 if enrollS3==1;
 gen privS4=enrollS4==0&lvreaS4==32 if enrollS3==1;
 gen leftS4=enrollS4==0&lvreaS4==33 if enrollS3==1;
 for any drop priv left: 
  replace XS4=XS3 if enrollS3==0 & enrollS4==0 \ 
  replace XS4=0 if enrollS3==0 & enrollS4==1;
 count if enrollS0==1|enrollF1==1|enrollS1==1|enrollS2==1|enrollS3==1|
  enrollS4==1;
 summ dropS4 leftS4 privS4;
  label var dropS4 "dropped out by Spr Yr 4";
  label var privS4 "transfer to Chic priv sch by Spr Yr 4";
  label var leftS4 "transfer to sch out of Chic by Spr Yr 4";

* See if leave-log files have substantially different information;
  * DROPCODE :
     1  = true dropout
     2  = unverified transfer over a month old
     3  = unverified transfer under a month old
     4  = verified transfer or no penalty leave (includes graduated midterm);
  for var dropS4 privS4 leftS4: 
   tab lvreaS4 dropcode if enrollS4==0 & X==1, m row;
  * there are only a very small number of cases that might be improved/corrected
    using these files.;

* Graduate;
 tab lvreaS4 enrollS4, m; 
 tab enrollF5 enrollS4, m;
 tab lvreaF5 enrollS4;
 gen gradF5=(lvreaS4==45|lvreaF5==45) if enrollS0==1|enrollF1==1|
  enrollS1==1|enrollS2==1|enrollS3==1|enrollS4==1;
 count if gradF5==1&(dropS4==1|privS4==1|leftS4==1);
 * does the code from the leavelog file help?;
 tab gradF5 if lvcode==45, miss;
  label var gradF5 "graduated by Fall Yr 5";
 summ gradF5;
 drop lvreaS4;

* Dropout/transfer;
 tab lvreaF5 if enrollS4==1 & enrollF5==0, miss;
 gen dropF5=enrollF5==0&lvreaF5>=34&lvreaF5<=66&lvreaF5~=45 if enrollS4==1;
 gen privF5=enrollF5==0&lvreaF5==32 if enrollS4==1;
 gen leftF5=enrollF5==0&lvreaF5==33 if enrollS4==1;
 for any drop priv left:
  replace XF5=XS4 if enrollS4==0 & enrollF5==0 \ 
  replace XF5=0 if enrollS4==0 & enrollF5==1;
 count if enrollS0==1|enrollF1==1|enrollS1==1|enrollS2==1|enrollS3==1|
  enrollS4==1|enrollF5==1;
 summ gradF5 dropF5 leftF5 privF5;
 count if gradF5==1 & (dropF5==1|leftF5==1|privF5==1);
  label var dropF5 "dropped out by Fall Yr 5";
  label var privF5 "transfer to Chic priv sch by Fall Yr 5";
  label var leftF5 "transfer to sch out of Chic by Fall Yr 5";

 * add subcategories included within dropping out;
 gen dieF5=dropF5==1&lvreaF5==41 if dropF5~=.;
 gen pregF5=dropF5==1&lvreaF5==44 if dropF5~=.;
 gen jailF5=dropF5==1&lvreaF5==35 if dropF5~=.;
  label var dieF5 "drop out b/c dead by Fall Yr 5";
  label var pregF5 "drop out b/c pregnant by Fall Yr 5";
  label var jailF5 "drop out b/c in jail by Fall Yr 5";

};

drop dropunit drpgrade dropcode leaved lvcode;
drop lvreaS1 lvreaS2 lvreaF1;
drop _merge;

qui compress;
doub2flt _all;
 
desc;
summ;

if ${n}==0{; global src=""; };
if ${n}==1{; global src="c:\projects\magnet schools\data\"; };
save "${src}magbase`1'", replace;

drop _all;

log close;
end;


/*** RUNNING PROGRAM ***/

doit 2000 00 1999 99 2001 01 2002 02 2003 03 2004 04;
doit 2001 01 2000 00 2002 02 2003 03 2004 04 2005 05;

** compressing files;
if ${n}==0{;
!gzip CASE_EXAMS\case*s.dta;
!gzip CEN_RELN\rel_trcts.dta;
!gzip CENSUS\allpub.dta;
!gzip CENSUS\blcrim94.dta;
!gzip CENSUS\cens00tr.dta;
!gzip GEOCODE\ap_geo.dta;
!gzip GEOCODE\pub_geo.dta;
!gzip GEOCODE\tracttotractdistances.dta; 
!gzip GEOCODE\IL_final_add.dta;
!gzip GEOCODE\IN_final_add.dta;
!gzip GEOCODE\census_*.dta;
!gzip PRIV\all_priv.dta;
!gzip allschbud.dta;
!gzip allm*.dta;
!gzip cpsmaglnk.dta;
!gzip grspr*.dta;
!gzip itbs*.dta;
!gzip leavelog0304.dta;
!gzip magnet*.dta;
!gzip sc*.dta;
!gzip tap*.dta;
!gzip tchrs99.dta;
};


 		****************;
 		*** PART II ***;
 		****************;

 capture log close;
 log using magbase.log, replace;


/***************************************************/
/***** COMBINING 2000 AND 2001 BASE DATA FILES *****/
/**************************************************/

program define getdata;

use magbase`1';

/** create sub-lottery codes **/

  gen str1 temp="0" if year==2000;
  replace temp="1" if year==2001;
  gen str7 sublotto=string(cunit)+substr(lotto,1,2)+temp; 
  replace sublotto="" if lotto=="";
   label var sublotto "admin lottery code";
  drop temp;

  disp "** get rid of a false lottery code **";
  gen temp=length(lotto);
  tab temp;
  tab lotto if temp>0 & temp<5;
  replace sublotto="" if lotto=="2820";
  replace lotto="" if lotto=="2820";
  drop temp;

  disp "** fix an incorrect grade **";
  tab gr if sublotto=="1580AA0";
  tab gradeS0 gradeF1 if gr=="06" & sublotto=="1580AA0";
  tab gradeS0 gradeF1 if gr=="07" & sublotto=="1580AA0";
  replace gr="08" if gr=="06" & sublotto=="1580AA0";

/** assign all students a current grade during the Spring of application **/

* note: this is to adjust for the problem with grade reports in the
  applications data ;

** first convert all grade variables to uniform scale (-1, 0, 1-12);

** Spring Yr 0 grade;
gen ngradeS0=gradeS0;
* pre-K (note that head start is pre-K);
replace ngradeS0=-1 if (gradeS0>=30&gradeS0<40)|(gradeS0>=60&gradeS0<100);
* kindergarten;
replace ngradeS0=0 if gradeS0>=40 & gradeS0<60;
* ungraded special ed;
replace ngradeS0=. if gradeS0>=20 & gradeS0<30;
tab ngradeS0;
 label var ngradeS0 "grade in Spring Yr 0 (-1 to 12)";

** Fall Yr 1 grade;
gen ngradeF1=gradeF1;
replace ngradeF1=-1 if (gradeF1>=30&gradeF1<40)|(gradeF1>=60&gradeF1<100);
replace ngradeF1=0 if gradeF1>=40 & gradeF1<60;
replace ngradeF1=. if gradeF1>=20 & gradeF1<30;
tab ngradeF1;
 label var ngradeF1 "grade in Fall Yr 1 (-1 to 12)";

** grade reported on application; 
gen ngradeap=real(gr);
replace ngradeap=-1 if ngradeap==30|ngradeap==40|gr=="PS";
replace ngradeap=0 if gr=="KG";
tab ngradeap;
 label var ngradeap "application reported grade (-1 to 12)";

** back-out actual application grade from Spr Yr 0 and Fall Yr 1 reports;
gen holdgrS0=ngradeS0;
replace holdgrS0=ngradeF1-1 if holdgrS0==.;
replace holdgrS0=-1 if holdgrS0==-2;
* adjust for retained and grade-skippers (as if applying from earlier or
  later grade than in);
gen temp1=(ngradeF1==ngradeS0) if ngradeF1~=. & ngradeS0~=.;
gen temp2=(ngradeF1-1==ngradeS0) if ngradeF1~=. & ngradeS0~=.;
gen temp3=(ngradeF1-2==ngradeS0) if ngradeF1~=. & ngradeS0~=.;
gen temp4=1-(temp1+temp2+temp3);
disp "** fraction w/Fall Yr 1 grade same as, 1+, and 2+ Spr Yr 0 grade **";
summ temp*;
tab ngradeS0 ngradeap if temp1==1;
replace holdgrS0=ngradeS0-1 if ngradeap==ngradeS0-1 & temp1==1;
tab ngradeS0 ngradeap if temp3==1;
replace holdgrS0=ngradeS0+1 if ngradeap==ngradeS0+1 & temp3==1;
summ holdgrS0;
drop temp*;

** use info on modal grade for students applying to the same school and 
 reporting the same grade on the application to fill in missing information;
egen igradeS0=mode(holdgrS0), by(cunit gr sublotto);
gen temp=(igradeS0==.);
summ igradeS0 temp;
drop temp;

* deal with cases with no single mode or no students enrolled in CPS
  applying from that grade; 
* indicator for reports grade ahead on application;
gen temp1=(holdgrS0+1==ngradeap) if holdgrS0~=. & ngradeap~=.;
egen temp2=mean(temp1), by(cunit gr);
egen temp3=mean(temp1), by(cunit);
replace temp2=temp3 if temp2==.;
disp "** % in sch-gr reporting next year's grade for missing cases **";
summ temp2 if igradeS0==., detail;
* assume reporting grade applying to if most applying to same school are;
replace igradeS0=ngradeap if igradeS0==. & temp2<.5;
replace igradeS0=ngradeap-1 if igradeS0==. & temp2>=.5 & temp2~=. & 
  ngradeap>-1;
* for remaining few, assume report correct grade;
replace igradeS0=ngradeap if igradeS0==.;
drop temp*;

* disp "** how often outside 1-year band of grade reported on appl? **";
list ngradeap igradeS0 gradeS0 gradeF1 if igradeS0<ngradeap-1 & ngradeap~=.;
list ngradeap igradeS0 gradeS0 gradeF1 if igradeS0>ngradeap+1 & igradeS0~=.;

** how well does our imputation do?;
gen badimput=(igradeS0~=holdgrS0) if igradeS0~=. & holdgrS0~=.;
disp "** fraction we would assign the incorrect grade to by grade **";
tabstat badimput, stats(n mean) by(holdgrS0) missing;
* note: for grades 6 and below we only miss about 5% of the time, however
  we do badly in grades around 8th grade when it appears several grades report
  8th on the application and true 8th graders dominate the mode. ; 

** replace imputation with actual grade if CPS Fall or Spring record exists;
replace igradeS0=holdgrS0 if holdgrS0~=.;
tab igradeS0;
 label var igradeS0 "imputed grade in Spring Yr 0 (-1 to 12)";

disp "** compare imputed values with original application grades **";
 gen gradediff=(igradeS0~=ngradeap);
 summ gradediff;
disp "** comparison for those in CPS in Spring or Fall **";
 summ gradediff if holdgrS0~=.;
disp "** comparison for those NOT in CPS in Spring or Fall **";
 summ gradediff if holdgrS0==.;
drop badimput holdgrS0 gradediff;

qui compress;

if `1'==2001{;
append using magbase;
order individ idseq sid year badmatch badmtch* baddemog
 pc dc lotto sublotto p comments sx rc gr sb appdate ngradeap igradeS0
 enrollS0 gradeS0 ngradeS0 latS0 longS0 tractS0* pri_* 
 rdgeS0 rdxilS0 mtxilS0 rdxil_1 mtxil_1 yy* xx* nn*
 unitS0 uS0name uS0type uS0p* uS0itbs uS0mnotaa
 cunit cuname cutype
 cupwhi cupblk cuphis cuplep cuploinc cupattnd cupdrop cupgrad cusize 
 cupnorms cumnotaa cutract cucrim cumedy cupov cumiles
 cuppe cupsped cupar cuptr cuuniv1 cuunivmeas cumstpls cuscrths cuscrtsub 
 cutcrt cueducmjr
 insch dinsch enrollF1 dropF1 privF1 leftF1 gradeF1 ngradeF1 tractF1
 unitF1 uF1name uF1type 
 uF1pwhi uF1pblk uF1phis uF1plep uF1ploinc uF1pattnd uF1pdrop uF1pgrad uF1size
 uF1pnorms uF1mnotaa uF1tract uF1crim uF1medy uF1pov uF1miles*
 uF1ppe uF1psped uF1par uF1ptr uF1univ1 uF1univmeas uF1mstpls uF1scrths 
 uF1scrtsub uF1tcrt uF1educmjr
 enrollS1 gradeS1 unitS1 aunitS1 aaS1 aS1* rdgeS1 rdxilS1 mtxilS1 dropS1 
 leftS1 privS1
 biompS1 biocpS1 biotpS1 wldmpS1 wldcpS1 wldtpS1 algmpS1 algcpS1 algtpS1
 eng1mpS1 eng1cpS1 eng1tpS1 
 gpaS1 mabsS1 tcrdS1 anyfS1 numfS1 crankS1
 enrollS2 gradeS2 unitS2 aaS2 rdgeS2 rdxilS2 mtxilS2 dropS2 leftS2 privS2
 hismpS2 hiscpS2 histpS2 geompS2 geocpS2 geotpS2 eng2mpS2 eng2cpS2 eng2tpS2
 gpaS2 mabsS2 tcrdS2 anyfS2 numfS2 crankS2
 enrollS3 gradeS3 unitS3 dropS3 leftS3 privS3 dieS3 pregS3 jailS3 lvreaS3 lvexpS3
 enrollS4 gradeS4 unitS4 dropS4 leftS4 privS4
 enrollF5 gradeF5 dropF5 leftF5 privF5 gradF5 dieF5 pregF5 jailF5 lvreaF5 lvexpF5;
};

save magbase, replace;
end;


/** RUNNING PROGRAM **/

getdata 2000;
getdata 2001;

clear; 
log close;

!del magbase2000.dta;
!del magbase2001.dta;



 		****************;
 		*** PART III ***;
 		****************;

 capture log close;
 log using magbasevalid.log, replace;

 use magbase;

 ** create new ID;
 descr idseq;
 gen str9 newid=idseq+"0" if year==2000;
 replace newid=idseq+"1" if year==2001;
  label var newid "ID that is unique by student x year";
 drop idseq;

*** KEY SCHOOLS MISSING FROM OUR DATA SET ***;

** elementary level;

 * elementary magnets;
 for num 6660 7860 2520 8000 3240 3420 4160 3490 3290 3690 3830 4890 4690 6920
 3370 4420 5030 5080 5240 5400 3550 7790 4250 5720 4920 6070 6190 3110 6250:
 tab year if cunit==X;
 * elementary classical schools;
 for num 2990 4750 5460 5940: tab year if cunit==X;
 * academic centers;
 for num 1710 1490 1580 1810: tab year if cunit==X;
 * Harlan H.S. was academic center in 2002 (may have been in 2001);
 tab cutype cuname if cunit==1350;
 tab year if cunit==1350;
 * regional gifted centers;
 for num 6660 2240 2270 2220 2730 4960 7240 7610 6460 5520: tab year if
 cunit==X;
 * Carnegie elem offered regional gifted center in 2002 (may have in 2001);
 tab cutype cuname if cunit==2630;
 tab year if cunit==2630; 
 tab gr if cunit==1350;
 * IB prep;
 for num 4480 5150: tab year if cunit==X;

 ** at elementary level:
   1810=Young only in dataset in 2000
   all other key elementary schools are in both years
   Harlan H.S. (1350) may have been an academic center in 2001, but is
     only in our data in 2000
   Carnegie Elem Sch (2630) may have offered regional gifted prog in 2001,
     but only to grades K-2;

** high school level;

 * lottery high school magnets;
 for num 1790 1820 1610: tab year if cunit==X;
 * selective high schools;
 for num 1060 1440 1450 1740 1500 1090 1810: tab year if cunit==X;
 * note: King (1760) was a regular h.s. until 2002-2003;
 * military schools;
 for num 1850 1800: tab year if cunit==X;
 * career academy;
 for num 1250 1010 1030 1300 1040 1460 1070 1110 1150 1590 1160:
  tab year if cunit==X;

 ** for high schools, we are in missing more (esp. in 2001):

  missing both years:
     1030 Dunbar Career Academy
     1300 Farragut Career Academy
     1040 Flower Career Academy
     1110 Chicago Vocational Career Academy
     1150 Simeon Career Academy
     1800 Bronzeville Military Academy
  
  only in our data set in 2000:
     1060 Jones College Prep 
     1450 Lindblom College Prep
     1740 Northside College Prep
     1500 Southside College Prep
     1090 Payton College Prep
     1810 Young
     1160 Westinghouse Career Academy
    
 only in our data set in 2001:
     1440 Lane Tech	;


/******************************************/
/******* DROP INVALID APPLICATIONS *******/ 
/****************************************/

*** IDENTIFY VALID UNEXPECTED CODES ***;

* note: below we use the "lotto" field to overwrite unexpected disposition
  codes for students in lotteries, so the few changes made to codes for
  lottery students before then will not matter;

** make comments more uniform;
replace comments=subinstr(comments,"  "," ",.);
replace comments=subinstr(comments,"  "," ",.);
replace comments=subinstr(comments,"  "," ",.);
replace comments=subinstr(comments,"  "," ",.);

** what codes exist;
tab dc, miss;
tab dc if sublotto~="", miss;

** generate indicator for legitimate code;
gen legit=dc=="S";
for any A P W R D L 1 3 4 5 6: replace legit=1 if dc=="X";

** replace the few that are clearly typos to missing;
* rule = 3 or fewer with that entry for any given school;
egen temp=count(cunit), by(cunit dc);
replace dc="" if temp<=3 & legit==0;
drop temp;

** check if appears to represent a legitimate category;
sort dc;
by dc: tab cunit if dc~="" & legit==0;

** the 7's are attributable to one school (1500=Southside);
tab cunit cuname if dc=="7";
tab dc if cunit==1500, missing;
tab comments if dc=="7" & cunit==1500;
count if lotto~="" & dc=="7" & cunit==1500;
* note: minimum requirements are based on 7th grade test scores;
for any A R 7: summ insch rdxil_1 rdxilS0 if cunit==1500 & dc=="X";
* these are rejected students, perhaps not meeting minimum requirements;
replace legit=1 if dc=="7" & cunit==1500;
* create new category R^ to indicate we assigned to rejected group;
replace dc="R^" if dc=="7" & cunit==1500;
* note: ideally we would want to separate eligible (i.e. meeting minimum
  requirements) from ineligible rejected applicants;

** the B's are attributable to one school (2820=Clissold);
tab cunit cuname if dc=="B";
tab dc if cunit==2820, missing;
tab comments if dc=="B" & cunit==2820;

** the C's are attributable to one school (1710=Kenwood Academy);
* here we can tell this means "does not meet criteria";
tab cunit cuname if dc=="C";
tab dc if cunit==1710, missing;
tab comments if dc=="C" & cunit==1710;
replace legit=1 if dc=="C" & cunit==1710;
replace dc="R^" if dc=="C" & cunit==1710;
* one student of this type was included in a lottery;
list sublotto lotto year sx rc if lotto~="" & dc=="R^" & cunit==1710;
tab dc if sublotto=="1710AC0", miss;

** the N's are attributable to 3 schools;
tab cunit cuname if dc=="N";
** 1580=Taft;
tab dc if cunit==1580, missing;
tab comments if dc=="N" & cunit==1580;
tab pc if dc=="N" & cunit==1580;
* these students are not applying to a lottery program, though sch has some;
tab dc if pc=="N" & cunit==1580;
* these students do not attend, but hard to believe rejected;
* perhaps they chose another school;
for any A N R: summ insch rdxil_1 rdxilS0 if dc=="X" & pc=="N" &  cunit==1580;
** 5460=Poe;
tab dc if cunit==5460, missing;
tab comments if dc=="N" & cunit==5460;
for any A N R: summ insch rdxil_1 rdxilS0 if dc=="X" & cunit==5460;
* pretty clear these students are rejected;
replace legit=1 if dc=="N" & cunit==5460;
replace dc="R^" if dc=="N" & cunit==5460;
count if lotto~="" & dc=="R^" & cunit==5460;
** 1810=Young;
tab dc if cunit==1810, missing;
for any N 6: tab comments if dc=="X" & cunit==1810;
for any A N 6: summ insch rdxil_1 rdxilS0 if dc=="X" & cunit==1810;
* here is pretty clear that N is a rejected group;
replace legit=1 if dc=="N" & cunit==1810;
replace dc="R^" if dc=="N" & cunit==1810; 
count if lotto~="" & dc=="R^" & cunit==1810;

** the T's are attributable to one school (1580=TAFT);
* here we can tell this means applying to AA school;
tab cunit cuname if dc=="T";
tab dc if cunit==1580, missing;
tab comments if dc=="T" & cunit==1580;
* one student who was entered in a lottery was a neighborhood student;
list sublotto lotto comments if dc=="T" & cunit==1580 & sublotto~="";
tab dc if sublotto=="1580AH1", miss;
* these will be dropped below;
replace legit=1 if dc=="T" & cunit==1580;
replace dc="6" if dc=="T" & cunit==1580;

** the U's are attributable to one school (4800=MCPHERSON);
tab cunit cuname if dc=="U";
tab dc if cunit==4800, missing;
tab comments if dc=="U" & cunit==4800;

** using lotto to fill in dc for a few cases;
gen temp1=length(lotto);
tab temp1;
count if temp1==5 & dc=="";
replace legit=1 if legit==0 & temp1==5 & dc=="";
gen str3 temp2=substr(lotto,-3,.);
replace dc="S" if temp1==5 & temp2=="000" & dc=="";
replace dc="R" if temp1==5 & temp2==">NS" & dc=="";
list lotto if temp1==5 & dc=="";
replace dc="W" if temp1==5 & dc=="";
drop temp*;

*** RECLASSIFY SOME 6'S AND MISSING CODES ***;

** reclassify those rejected because do not meet selective criteria to "R^" 
 to separate from other 6's or missings;
 gen temp=index(comments,"RITERI") if dc=="6"|legit==0;
 for any "DNC" "UNQUALIF" "ACADEMI" "BELOW STAND" "DOES NOT QUAL" 
   "DOES NOT MEET" "SLIGHTLY LOW": replace temp=index(comments,"X") if temp==0;
 tab comments if temp>0 & temp~=.;
 tab dc if temp>0 & temp~=., missing;
 replace legit=1 if temp>0 & temp~=.;
 replace dc="R^" if temp>0 & temp~=.;
 drop temp;

** separate denied late applications from other 6's and missings;
 * note: had to be postmarked by 1/21/00 in 2000, and by 1/19/01 in 2001;
 gen temp=index(comments,"LATE") if dc=="6"|legit==0;
 for any "AFTER D" "REC'D" "RECEI": replace temp=index(comments,"X") if
  temp==0;
 tab comments if temp>0 & temp~=.;
 replace temp=0 if comments=="FAMACULATE HEART";
 tab dc if temp>0 & temp~=., missing;
 replace dc="L" if temp>0 & temp~=.;
 replace legit=1 if temp>0 & temp~=.;
 drop temp appdate;

** separate out those rejected because no space was available;

* using comments;
 egen temp=count(cunit), by(dc comments);
 tab comments if dc=="3" & temp>5;
 drop temp;
 gen temp=index(comments,"NOT ACCEPTING") if dc=="6"|legit==0;
 replace temp=index(comments,"OVER ENROLL") if temp==0;
 tab comments if temp>0 & temp~=.;
 replace legit=1 if temp>0 & temp~=.;
 replace dc="3" if temp>0 & temp~=.;
 drop temp;

* using reports for other students applying to the same school;
 gen temp1=(dc=="3");
 egen temp2=mean(temp1), by(cunit year);
 summ temp2, detail;
 summ temp2 if temp2>0, detail;
 egen temp3=tag(cunit year);
 sort cunit year;
 list cunit cuname cutype year if temp2>.95 & temp3==1;
 gen temp4=(dc=="S"|dc=="A"|dc=="P"|dc=="W"|dc=="R");
 summ temp4 if temp2>.95 & temp2~=.;
 tab dc if temp2>.95 & temp2~=., miss;
 replace dc="3" if temp2>.95 & temp2~=. & (dc=="6"|legit==0);
 replace legit=1 if temp2>.95 & temp2~=. & dc=="3";

* do the same for others applying to same program and grade;
 egen temp5=mean(temp1), by(cunit year gr pc);
 summ temp5, detail;
 summ temp5 if temp5>0 & temp5~=., detail;
 summ temp4 if temp5>.75 & temp5~=.;
 replace dc="3" if temp5>.75 & temp5~=. & temp4==0 & (dc=="6"|legit==0);
 replace legit=1 if temp5>.75 & temp5~=. & temp4==0 & dc=="3";
 drop temp*;

*** REPLACE DC CODES USING LOTTERY OUTCOMES ***;

** seem to have adjusted DC codes based on later information;
* for example, some selected students were recoded as other than "S"
  to reflect their decision over whether to attend or not;
gen str3 temp=substr(lotto,-3,.);
tab temp; 
tab dc if temp=="000", miss;
* most withdrew if not assigned "S";
tab comments if temp=="000" & dc~="S";
replace dc="S" if temp=="000";
tab dc if temp==">NS", miss;
tab comments if temp==">NS" & dc~="R";
replace dc="R" if temp==">NS";
tab dc if temp>="001" & temp<="033", miss;
tab comments if temp>="001" & temp<="033" & dc~="W", miss;
replace dc="W" if temp>="001" & temp<="033";
tab dc if sublotto~="";
summ legit if sublotto~="";
drop temp;

*** NOW DROP INVALID APPLICATIONS ***;

* note: will not drop any students in lotteries since all have valid codes;

** count of total number of applications/students before exclusions;
count;
sort newid;
count if newid~=newid[_n-1];

** before dropping any applications, create count by student-year; 
egen napptot=count(cunit), by(newid);
 label var napptot "total # of apps submitted by student";

** Drop students imputed to be enrolled in the 12th grade;
summ enrollF1 if ngradeS0==12;
tab ngradeS0 if igradeS0==12, miss;
egen temp=mean(ngradeS0==12|igradeS0==12), by(sublotto);
summ temp if sublotto~="" & temp>0, detail;
tab igradeS0 if temp==.25;
tab dc if temp==.25;
drop if ngradeS0==12|igradeS0==12;
drop temp;

** Drop records that are duplicate or incomplete applications;
 gen temp1=(dc=="D");
 tab comments if temp1==1, missing;
 gen temp2=index(comments,"DUPL") if dc=="6"|legit==0;
 for any "NO DOB" "NO ADD" "INCOMPL" "NO ETHNI" "SAME APP" "WRONG APP" 
  "WRONG I.D." "WRONG ID" "WRONG SCHOOL" "MISTAKE" "LIST ANOTHER"
  "GRADES NOT AV": replace temp2=index(comments,"X") if temp2==0;
 tab comments if temp2>0 & temp2~=.;
 tab dc if temp2>0 & temp2~=., missing;
 replace temp1=1 if temp2>0 & temp2~=.;
 drop if temp1==1;
 drop temp*;

** Drop late applications;
 drop if dc=="L";

** Drop age inappropriate applications;
 gen temp1=(dc=="4");
 tab comments if temp1==1, missing;
 gen temp2=index(comments,"YOUNG") if dc=="6"|legit==0;
 tab comments if temp2>0 & temp2~=.;
 replace temp2=0 if comments=="WILL ATTEND WHITNEY YOUNG" & temp2>0 &
  temp2~=.;
 tab dc if temp2>0 & temp2~=., missing;
 replace temp1=1 if temp2>0 & temp2~=.;
 drop if temp1==1;
 drop temp*;

** Drop if no program available at grade-level requested;
 gen temp1=(dc=="5");
 tab comments if temp1==1, missing; 
 gen temp2=index(comments,"NO PROG") if dc=="6"|legit==0;
 for any "GRADE NOT" "INCORRECT GR" "ERROR" "NOT APPROP" "DO NOT HAVE 9TH"
  "NO SELF-CONT": replace temp2=index(comments,"X") if temp2==0;
 tab comments if temp2>0 & temp2~=.;
 tab dc if temp2>0 & temp2~=., missing;
 replace temp1=1 if temp2>0 & temp2~=.;
 drop if temp1==1;
 drop temp*;

** Drop if non-resident or unecessary application to own AA;
gen temp=index(comments,"OUR A") if dc=="6"|legit==0;
 for any AA A.A ATTENDA LIVE RESID MOVED AREA HOMELESS "ADDRESS NOT" 
  "ALREADY ENR" CURRENT "OUT OF" "HOME SCHOOL" "NEIGHBORHOOD":
  replace temp=index(comments,"X") if temp==0;
 tab comments if temp>0 & temp~=.;
 replace temp=0 if temp>0 & temp~=. & dc=="" & 
   (comments=="INDIANA RESIDENT RELOCATING CHGO"|
   comments=="SIBLING IN NEIGHBORHOOD");
 tab dc if temp>0 & temp~=., missing;
 drop if temp>0 & temp~=.;
 drop temp;

* Orozco has both a bilingual regional gifted center and an arts magnet 
  cluster.  Drop applications from non-LEP students to regional center;
 tab cuname if comments=="NOT LEP";
 tab cunit if comments=="NOT LEP";
 tab dc if comments=="NOT LEP";
 tab pc if comments=="NOT LEP";
 summ xxhisp if pc=="U" & comments~="NOT LEP" & cunit==7610;
 summ xxhisp if pc=="U" & comments=="NOT LEP" & cunit==7610;
 drop if comments=="NOT LEP";
 drop legit;

** creat count of number of valid applications submitted by students;
 egen napp=count(cunit), by(newid);
  label var napp "number of valid applications";

** get sample count;
count;
sort newid;
count if newid~=newid[_n-1];

*** NOW DROP IF MULTIPLE STUDENTS APPEAR TO SHARE SAME ID;

** Indicator for basic demographics differ across applications;
summ bad*;
for num 1/3 \ var sx xxage rc: egen tempX=nvals(Y), by(newid) \
 replace tempX=(tempX>1&tempX~=.) \ tab tempX, miss \ 
 summ bad* if tempX==1;
* classify as bad case if two of sex, birthdate, and race don't match; 
gen temp4=(temp1==1&temp2==1)|(temp1==1&temp3==1)|(temp2==1&temp3==1);
summ bad* if temp4==1;
summ napp if temp4==1, detail;

** Indicator for multiple observations for student in same lottery;
* note: it looks like some of these may have legitimately been entered
2x in the same lottery (e.g. see individ="00031626" & individ="00031696"),
but still unclear then how to treat them;
egen temp5=count(cunit) if sublotto~="", by(newid sublotto);
replace temp5=(temp5>1&temp5~=.);
tab temp5;
summ bad* if temp5==1;
summ temp4 if temp5==1;

** Combined indicator for problem case;
* include cases that originally had multiple sid's as well;
gen temp6=temp4==1|temp5==1|badmtch1==1;
summ temp6;
summ bad* if temp6==1;

* are the losses concentrated in any one lottery;
egen temp7=mean(temp6) if sublotto~="", by(sublotto);
summ temp7, detail;
summ temp7 if temp7>0, detail;
summ temp7 if temp7>0 & igradeS0==8, detail;

* are winners systematically more/less likely to share ID?;
gen temp8=(dc=="S") if sublotto~="";
areg temp6 temp8, absorb(sublotto); 
areg temp6 temp8 if enrollS0==1 & igradeS0==8, absorb(sublotto); 
drop if temp6==1;

* redefine bad match indicators;
summ badmtch2 badmatch;
drop badmtch1 badmatch;
rename badmtch2 badmatch;

** Drop students with >35 and >15 applications depending on grade level;
 tab igradeS0, miss;
 summ napp if igradeS0<8, detail;
 summ napp if igradeS0>=8 & igradeS0<12, detail;
 summ bad* if napp<=35 & igradeS0<8;
 summ bad* if napp>35 & igradeS0<8;
 summ bad* if napp<=15 & igradeS0>=8 & igradeS0<12;
 summ bad* if napp>15 & igradeS0>=8 & igradeS0<12;
 gen temp9=(napp>30) if igradeS0<8;
 replace temp9=(napp>15) if igradeS0>=8 & igradeS0<12;
 summ temp9;
 areg temp9 temp8, absorb(sublotto);
 areg temp9 temp8 if enrollS0==1 & igradeS0==8, absorb(sublotto);
 drop if temp9==1;
 drop temp*;
 * !Note: may want to use different rules if we do not focus on 8th graders
 applying from inside the CPS because of apparent selection issues;

** will test sensitivity to excluding other possible problem cases;
 summ bad*;

** get sample count;
count;
sort newid;
count if newid~=newid[_n-1];

/*******************************************/
/***** CREATING SCHOOL TYPE VARIABLES *****/ 
/*****************************************/

***VARIOUS TYPES OF ELEMENTARY SCHOOLS (Grades PK to 8 )***;

/*
 Magnet Schools 
     - listed in schooltype 
     - 35 total, incl 4 classical schools
 Magnet Clusters
 4 Classical Elementary Schools 
     - All magnets, all require testing
     - 2990=Decauter, 4750=McDade, 5460=Poe, 5940=Skinner
 Academic Centers 
     - grades 7 to 12, testing required 
     - Kenwood=1710, Morgan Park=1490, Taft=1580, Young=1810
     Note: for high school grades, Young classified as a college prep
     Note: these are special programs within larger schools       
 10 Regional Gifted Centers 
     - Programs within Schools (either magnet or general) that require testing 
     - must be at 90th percentile
     - Beasley=6660, Beaubien=2240, Bell=2270, Edison=2220, Greeley=2730, 
       Keller=4960, Lenart=7240, Orozco=7610, Pritzker=6460, Pulaski=5520
     - note: Beasley is in a magnet; 2240, 2270, 2730, 7610, 6460, and 
       5520 are all part of a larger school
 International Baccalaureate Preparatory Programs 
     - programs within larger schools
     - for 6th-8th graders scoring above 90th %ile 
     - Lincoln=4480 and Ogden=5150
 Note: Hope is self-labeled a college prep, but is treated as a general sch;
*/

/* identifying secondary units that serve elementary schools:

 Based on 501 master file:
   - other than alternative or special needs schools and academic prep schools,
     it appears that Crane, Lindblom and Senn may legitimately accept kids in 
     7th and 8th grade

. tab cursc501 if cursc501<2000&cursc501>=1000 & granu501<=8

   unit number |
        in 501 |
      (same as |
         unit) |      Freq.     Percent        Cum.
   ------------+-----------------------------------
Alt    	  1120 |        170       10.86       10.93  Safe Sch Alternative
APC    	  1190 |        111        7.09       18.02  Acad Prep
Gen  	+ 1270 |         68        4.35       22.36  Crane Tech
Tch/CP  + 1450 |        140        8.95       31.31  Lindblom
         *1490 |        208       13.29       44.60  Morgan Park
Gen/Mag + 1540 |        108        6.90       51.50  Senn Metro
Gen     + 1570 |         23        1.47       53.04  Sullivan
         *1580 |        100        6.39       59.42  Taft
         *1710 |        151        9.65       69.07  Kenwood
Cht       1720 |        128        8.18       77.25  Act Charter
SpNd/Preg 1750 |         32        2.04       79.30  Simpson Alt High
         *1810 |        221       14.12       93.42  Young
SpNd/Preg 1900 |         17        1.09       94.70  Arts of Living
Cht       1960 |         58        3.71       98.40  Perspect Charter
SpNd/Preg 1970 |         25        1.60      100.00  Tesla Alternative
   ------------+-----------------------------------
         Total |       1565      100.00

	* = academic center
	+ = why?

** schools that span both elementary and secondary grades;
* Elementary units with grades 9 or 10:
  2420, 2490, 4130, 5640, 6630, 8070 
* Secondary units with grades 7 or 8 (other than academic centers):
  1270, 1450, 1540, 1570, 1720, 1960
 
*/

/** Create classification categories for APPLICATION schools **/

**Classical Schools;
 
 gen byte cu_clas=cunit==2990|cunit==4750|cunit==5460|cunit==5940;
  label var cu_clas "App Sch = EL, Classical Acad";

 * only serve grades K-8;
 tab ngradeap if cu_clas==1;
 tab igradeS0 if cu_clas==1;
 count if lotto~="" & igradeS0>7 & cu_clas==1;
 replace igradeS0=ngradeap if cu_clas==1 & igradeS0>7 & igradeS0~=.;

 tab dc if cu_clas==1, miss;
 sort dc;
 tabstat insch if cu_clas==1, by(dc) miss;
 * missing appear uniformly to be rejects;
 replace dc="R^" if dc=="" & cu_clas==1;
 count if lotto~="" & cu_clas==1;

**Elementary magnets;
 
 * regular magnets without attendance areas;
 gen byte cu_magr=0;
 for num 6660 7860 8000 3420 4890 4690 4420 5030 5080 5400 7790
 5720 4920 3110 6250: replace cu_magr=1 if cunit==X;
  label var cu_magr "App Sch = EL, Regular Magnet";
 
 * regular magnets with attendance areas;
 gen byte cu_maga=0;
 for num 3490 3290 3370 3550: replace cu_maga=1 if cunit==X;
  label var cu_maga "App Sch = EL, Reg Mag w/att area";

 * magnets not subject to consent decree (scholastic academies);
 gen byte cu_mags=0;
 for num 2520 3240 4160 3690 3830 6920 5240 4250 6070 6190: replace cu_mags=1
  if cunit==X;
  label var cu_mags "App Sch = EL, Magnet not s.t. decree";

 gen cu_elmag=(cu_magr+cu_maga+cu_mags);
 tab cu_elmag, miss;
  label var cu_elmag "App Sch = EL, Magnet any type";
 tab ngradeap if cu_elmag==1;
 tab igradeS0 if cu_elmag==1;
 tab gradeS0 if cu_elmag==1 & igradeS0>7;
 replace igradeS0=ngradeap if cu_elmag==1 & igradeS0>7;
 replace igradeS0=7 if cu_elmag==1 & igradeS0>7;

 * did we get all of those classified as magnets?;
 tab cuname if cutype=="Magnet" & cunit>=2000 & cu_elmag==0;

 * how many have valid data?;
 tab dc if cu_elmag==1, miss;

 * do missing codes look like "all admit categories"?;
 for any 3 6 A P S W R: summ insch if dc=="X" & cu_elmag==1;
 summ insch if dc=="" & cu_elmag==1;

 * note: I was able to track some program codes (e.g. for 3420 program code 
  S is for the sibling lottery), but are not very systematic;

 * only information can use to separate out Beasley regional gifted center
   is whether lottery information exists or not;
   tab pc if cunit==6660;
   tab dc if cunit==6660 & lotto=="" & year==2000, miss;
   tab dc if cunit==6660 & lotto=="" & year==2001, miss;
   replace cu_magr=0 if cunit==6660 & lotto=="";
   replace cu_elmag=0 if cunit==6660 & lotto=="";
   * missing for the other program appear to be rejects;
   summ insch if dc=="S" & cunit==6660 & cu_magr==0 & year==2001;
   summ insch if dc=="" & cunit==6660 & cu_magr==0 & year==2001;
   replace dc="R^" if dc=="" & cunit==6660 & cu_magr==0 & year==2001; 

**Academic Centers;

 gen byte cu_acad=(cunit==1710|cunit==1490|cunit==1580|cunit==1810);
  label var cu_acad "App Sch = EL, Academic Center";
 tab ngradeap if cu_acad==1;
 tab igradeS0 if cu_acad==1;
 gen temp=(lotto~="");
 tab cunit if temp==1 & cu_acad==1;
 * should be no lotteries for academic centers, but some schools have other
   programs at higher grades that should run lotteries;
 summ temp if (cunit==1580|cunit==1710) & ngradeap<8;
 summ temp if (cunit==1580|cunit==1710) & ngradeap>=8;
 tab pc year if cunit==1580, miss;
 tab pc year if cunit==1710, miss;
 drop temp;

 * program codes are a decent indicator for whether the program is
   the academic center or another within the school;
 * for Young, not much of a program if there is one;
 tab year if cunit==1810;
 tab gradeS0 gr if cunit==1810, miss;
 tab gradeF1 gradeS0 if gradeS0<8 & cunit==1810;
 tab pc if gradeS0<8 & cunit==1810, miss;
 tab pc if gradeS0>=8 & gradeS0~=. & cunit==1810, miss;
 * move elementary applicants to the high school category for now;
 replace igradeS0=8 if igradeS0<8 & cunit==1810;
 replace cu_acad=0 if cunit==1810;
 * for the other schools, use the program codes;
 gen temp=6 if gradeS0==6;
 for num 7/8: replace temp=X if gradeS0==X;
 for num 1710 1490 1580: tab pc temp if cunit==X & year==2000, miss;
 for num 1710 1490 1580: tab pc temp if cunit==X & year==2001, miss;
 drop temp;
 gen str1 temp1=pc;
 replace temp1="" if sublotto~="";
 egen temp2=mode(ngradeS0), by(cunit year sublotto temp1);
 list cunit pc sublotto gradeS0 igradeS0 if temp2==. & cu_acad==1;
 tab temp2 if cu_acad==1, miss;
 * shift elementary applicants to 8th grade if not imputed to be applying
   to the academic center;
 tab dc if gradeS0<8 & temp2~=6 & cu_acad==1, miss;
 replace igradeS0=8 if igradeS0<8 & temp2~=6 & cu_acad==1;
 replace cu_acad=0 if temp2~=6 & cu_acad==1;
 drop temp*;

 * should not be any lotteries;
 tab sublotto if lotto~="" & cu_acad==1;

 tab igradeS0 if cu_acad==1;
 replace igradeS0=ngradeap if cu_acad==1 & igradeS0<6;
 replace igradeS0=6 if cu_acad==1 & igradeS0<6;
 replace igradeS0=ngradeap if cu_acad==1 & igradeS0>7;
 replace igradeS0=7 if cu_acad==1 & igradeS0>7;

 * can identify a few categories that look like rejects;
 for num 1710 1490 1580: tab dc insch if cunit==X & year==2000 &
   cu_acad==1, row miss;
 for num 1710 1490 1580: tab dc insch if cunit==X & year==2001 & 
   cu_acad==1, row miss;
 replace dc="R^" if cunit==1710 & cu_acad==1 & dc=="" & year==2000;
 replace dc="R^" if cunit==1490 & cu_acad==1 & dc=="" & year==2000;

**Regional Gifted;
 
 gen byte cu_rgif=cunit==2240|cunit==2270|cunit==2220|cunit==2730|
   cunit==4960|cunit==7240|cunit==7610|cunit==6460|cunit==5520;
 replace cu_rgif=1 if cunit==6660 & cu_magr==0;
  label var cu_rgif "App Sch = EL, Regional Gifted";

 * should all be below 8th grade;
 tab igradeS0 if cu_rgif==1;
 replace igradeS0=ngradeap if igradeS0>7 & igradeS0~=. & cu_rgif==1;
 replace igradeS0=7 if igradeS0>7 & igradeS0~=. & cu_rgif==1;

 * these are only regional gifted centers;
 gen temp=(cunit==6660|cunit==2270|cunit==2220|cunit==4960|cunit==7240)
  if cu_rgif==1;
 * should not have any lotteries;
 tab dc if temp==1, miss;
 count if lotto~="" & temp==1;
 * can we fill in any missing codes?;
 for num 6660 2270 2220 4960 7240: summ insch if cunit==X & cu_rgif==1 & 
  (dc=="S"|dc=="A") & year==2000 \ summ insch if cunit==X & cu_rgif==1 & 
  (dc=="R"|dc=="R^") & year==2000 \ summ insch if cunit==X & cu_rgif==1 & 
  dc=="" & year==2000;
 for num 6660 2270 2220 4960 7240: summ insch if cunit==X & cu_rgif==1 & 
  (dc=="S"|dc=="A") & year==2001 \ summ insch if cunit==X & cu_rgif==1 & 
  (dc=="R"|dc=="R^") & year==2001 \ summ insch if cunit==X & cu_rgif==1 & 
  dc=="" & year==2001;
 * only one case that looks clear;
 replace dc="R^" if cunit==2220 & dc=="" & year==2001;
 drop temp;

 * these have LEP gift programs and other non-regional gifted programs too;
 gen temp1=(cunit==2730|cunit==7610|cunit==5520) if cu_rgif==1;
 * should not have any lotteries if part of the regional center;
 tab dc if temp1==1, miss;
 gen temp2=(lotto~="");
 tab cunit year if lotto~="" & temp1==1;
 for any 2730 7610 5520: tabstat temp2 xxhisp if cunit==X & 
  year==2000, by(pc) miss;
 for any 2730 7610 5520: tabstat temp2 xxhisp if cunit==X & 
 year==2001, by(pc) miss;
 summ xxhisp if lotto~="" & temp1==1;
 summ xxhisp if lotto=="" & temp1==1;
 * for now, divide up based on whether has a lottery code or not;
 gen byte cu_eloth=0;
 replace cu_rgif=0 if temp1==1 & lotto~="";
 replace cu_eloth=1 if temp1==1 & lotto~="";
 replace temp1=0 if temp1==1 & lotto~="";

 * can we fill in any missing codes?;
 count if temp1==1;
 tab dc if temp1==1, miss;
 summ insch if temp1==1;
 drop temp*; 

 * remaining regional gifted centers that also have other programs;
 gen temp1=(cunit==2240|cunit==6460) if cu_rgif==1;
 tab dc if temp1==1, miss;
 gen temp2=(lotto~="");
 tab cunit year if lotto~="" & temp1==1;
 tab pc temp2 if cunit==2240 & year==2000, miss;
 tab pc temp2 if cunit==2240 & year==2001, miss;

 * for now, divide up based on whether has a lottery code or not;
 replace cu_rgif=0 if temp1==1 & lotto~="";
 replace cu_eloth=1 if temp1==1 & lotto~="";
 replace temp1=0 if temp1==1 & lotto~="";

 * can we fill in any dc codes?;
 for any 2240 6460: tab dc if cunit==X & temp1==1 & year==2000, miss;
 for any 2240 6460: tab dc if cunit==X & temp1==1 & year==2001, miss;
 summ insch if dc=="" & cunit==6460 & temp1==1 & year==2001;
 drop temp*;

**IB Prep programs;

 gen byte cu_ibprep=(cunit==4480|cunit==5150);
  label var cu_ibprep "App Sch = EL, IB Prep program";
 tab igradeS0 if cu_ibprep==1;
 replace igradeS0=ngradeap if igradeS0<5 & cu_ibprep==1;
 replace igradeS0=5 if igradeS0<5 & cu_ibprep==1;
 replace igradeS0=ngradeap if igradeS0>7 & cu_ibprep==1;
 replace igradeS0=7 if igradeS0>7 & cu_ibprep==1;
 count if lotto~="" & cu_ibprep==1;
 tab cunit year if dc~="" & cu_ibprep==1;
 tab insch dc if cunit==4480 & year==2001, miss;
 tab insch dc if cunit==5150 & year==2000, miss;
 * missings appear to have been accepted in those years;
 replace dc="A^" if dc=="" & cunit==4480 & year==2001;
 replace dc="A^" if dc=="" & cunit==5150 & year==2000;

** indicator for all selective types;
 gen cu_eltst=cu_clas+cu_acad+cu_rgif+cu_ibprep;
  label var cu_eltst "App Sch = EL, test sch of any kind";

**Other/general Schools;

 gen temp1=cu_eltst+cu_elmag+cu_eloth;
 tab temp1;
 tab cutype if cunit>=2000 & temp1==0 & igradeS0<8, miss;
 tab cunit cuname if cutype=="College Prep"&cunit>=2000&temp1==0&igradeS0<8;
 * these are all academic centers;
 count if temp1==1 & cunit<2000;
 tab cuname if temp1==1 & cunit<2000;

 * making sure students are in the correct grades;
 tab igradeS0 if temp1==1;
 tab igradeS0 if cunit>=2000 & temp1==0;
 * of these, 4130, 6630, & 8070 are regular schools with 9th and 10th graders;
 tab cunit if igradeS0>7 & cunit>=2000;
 count if lotto~="" & cunit==4130;
 count if lotto~="" & cunit==6630;
 tab sublotto gr if cunit==8070 & lotto~="";
 tab gr igradeS0 if cunit==8070 & lotto~="";
 replace igradeS0=7 if igradeS0==8 & sublotto=="8070AC1";
 * make sure move all students in the same sublottery to either elementary
   or secondary sample using modal grade;
 egen temp2=mean(igradeS0>7) if sublotto~="", by(cunit sublotto);
 summ temp2 if temp2>0 & temp2~=. & cunit>=2000, detail;
 replace igradeS0=7 if igradeS0>7 & cunit>=2000 & temp2<=.5;
 tab igradeS0 if cunit>=2000 & temp2>.5 & temp2~=.;

 * categorize remaining elementary programs as other;
 replace cu_eloth=(cunit>=2000 & igradeS0<8) if temp1==0;
  label var cu_eloth "App Sch = EL, all non-magnet/non-test schs";
 replace temp1=1 if cu_eloth==1;

 * also include elementary students attending high schools that serve these
   grades (if those schools are not already otherwise classified above);
 tab cunit if cunit<2000 & igradeS0<8 & temp1==0;
 egen temp3=mean(igradeS0<8) if sublotto~="", by(cunit sublotto);
 tab temp3 if cunit>=2000;
 summ temp3 if cunit<2000 & temp1==1;
 summ temp3 if temp3>0 & temp3~=. & cunit<2000 & temp1==0, detail;
 tab sublotto gradeS0 if temp3>.05 & temp3~=. & cunit<2000 & temp1==0;
 replace igradeS0=8 if igradeS0<8 & cunit<2000 & temp1==0 & temp3~=.;
 replace cu_eloth=1 if cunit<2000 & igradeS0<8 & temp1==0;
 replace temp1=1 if cu_eloth==1;
 
 * should have classified all elementary students;
 tab temp1 if igradeS0<8, miss;
 drop temp*;

** Set all of these variables to missing for secondary students;

 for var cu_el* cu_clas cu_mag* cu_acad cu_rgif cu_ibprep: replace X=. if
  igradeS0>=8;

/** Create classification categories for FALL ENROLLMENT schools **/

 * note: "f_" is an indicator for Fall school;

 tab uF1type if gradeF1<=8;

 gen byte f_eltst=0 if unitF1~=.;
 for num 2990 4750 5460 5940: replace f_eltst=1 if unitF1==X;
 for num 1710 1490 1580 1810: replace f_eltst=1 if unitF1==X;
 for num 2240 2270 2220 2730 4960 7240 7610 6460 5520:
  replace f_eltst=1 if unitF1==X;
  label var f_eltst "elementary test sch Fall Yr 1";

 gen byte f_elmag=0 if unitF1~=.;
 * incorporating Beasley=6660;
 for num 6660 7860 8000 3420 3490 3290 4890 4690 3370 4420 5030 5080 5400
 3550 7790 5720 4920 3110 6250 2520 3240 4160 3690 3830 6920 5240 4250 6070 
 6190: replace f_elmag=1 if unitF1==X;
  label var f_elmag "magnet elementary sch Fall Yr 1";
 * is the magnet program more important for Beasley?;
 summ cu_magr cu_rgif if cunit==6660;

 gen byte f_elchrt=(uF1type=="Charter")&(unitF1>=2000) if unitF1~=.;
  label var f_elchrt "charter school elem Fall Yr 1";
 
 gen temp=f_eltst+f_elmag+f_elchrt;
 tab temp;
 tab uF1type if temp==0 & unitF1>=2000; 
 tab unitF1 if uF1type=="College Prep" & temp==0 & unitF1>=2000;
 gen byte f_eloth=(unitF1>=2000&temp==0) if unitF1~=.;
  label var f_eloth "other general elem sch Fall Yr 1";
 replace temp=temp+f_eloth;

 * is this defined for all applicants to elementary schools?;
 tab temp if igradeS0<8;
 tab uF1type if temp==0 & igradeS0<8;
 tab gradeS0 if temp==0 & igradeS0<8;
 for any Technical "College Prep" Magnet "Magnet/Career Acad":
  tab uF1name if uF1type=="X" & temp==0 & igradeS0<8;
 replace f_eltst=1 if temp==0 & igradeS0<8 & (unitF1==1060|unitF1==1440|
  unitF1==1450|unitF1==1740|unitF1==1500|unitF1==1090|unitF1==1810);
 replace f_elmag=1 if temp==0 & igradeS0<8 & 
  (unitF1==1790|unitF1==1820|unitF1==1610);
 replace f_elchrt=1 if temp==0 & igradeS0<8 & uF1type=="Charter";
 replace temp=f_eltst+f_elmag+f_elchrt+f_eloth;
 tab uF1type if temp==0 & igradeS0<8;
 replace f_eloth=1 if temp==0 & igradeS0<8;

 * set to missing for secondary students;
 for var f_eltst f_elmag f_elchrt f_eloth: replace X=. if igradeS0>=8;
 
** Check classification categories;

 * this should sum to one;
 count if igradeS0<8 & enrollF1==1;
 replace temp=f_eltst+f_elmag+f_elchrt+f_eloth;
 tab temp if igradeS0<8, miss;
 drop temp;

***VARIOUS TYPES OF SECONDARY SCHOOLS (Grades 9 to 12)***;

/*

 Academic Prep Centers (9)
 	- 1080, 1100, 1170, 1180, 1190, 1290, 1660, 1980, 1990
 	- transition centers for kids who were retained in 8th,
 	but too old to remain in elementary school
 
 Regular magnets (3) 
     - no selective admissions, lotteries
     - chic agric=1790, curie=1820, von steuben=1610
       * Note: Curie labeled as both magnet & career academy - we will 
       consider it a magnet for now
 
 Selective enrollment high schools
     - young=1810,northside=1740,payton=1090,jones=1060,king=1760,
       lindblom=1450,southside(gwendolyn brooks)=1500,lane tech=1440
     * note: King is still not a regional college prep and is a general
       high school -- was supposed to become one in 2001-02, now scheduled 
       for 2002-03

 Career academies (11)
     - those included in app data are: 
      	chic voc=1010,1070=prosser,westinghouse=1160,calumet=1250,manley=1460,
        tilden=1590
     - others not included in app data are:   
        Flower=1040,Simeon=1150,Dunbar=1030,Farragut=1300,Richards=1100
 
 Military academies (2)
     - testing req
     - carver=1850, chicago military = 1800 (no apps in our data)

*/

/** Create Classification Categories for APPLICATION High Schools **/
 
tab cutype if gradeS0>=8;
gen templott=(lotto~="");

**Career Academies;

 gen byte cu_hsvoc=cutype=="Career Academy" if igradeS0>=8;
  label var cu_hsvoc "App Sch = HS, Career Academy";
 tab cunit if cu_hsvoc==1;
 tab cuname if cu_hsvoc==1 & cunit==1820; 
 tab cutype year if cunit==1820;
 replace cu_hsvoc=0 if cunit==1820 & cu_hsvoc==1;
 tab dc if cu_hsvoc==1, miss;
 summ templott if cu_hsvoc==1;
 tab cunit if templott==1 & cu_hsvoc==1;
 tab dc if templott==1 & cu_hsvoc==1;
 * fill in for missing dc codes when possible;
 tab cunit if cu_hsvoc==1 & dc=="";
 for num 1010 1070: tab dc insch if cunit==X & year==2000, miss row;
 for num 1010 1070: tab dc insch if cunit==X & year==2001, miss row;
 replace dc="A^" if (dc==""|dc=="0") & cunit==1070 & year==2000;
 replace dc="R^" if dc=="" & (cunit==1010|cunit==1070) & year==2001;

**Selective Enrollment High Schools;

 gen byte cu_hstst=0 if igradeS0>=8;
 * note: excluding King (1760) because still not a College Prep;
  for num 1060 1440 1450 1740 1500 1090 1810: replace cu_hstst=1 if 
  cunit==X & cu_hstst==0;
 tab cutype if cu_hstst==1;
 tab cutype if cunit==1760;
 label var cu_hstst "App Sch = HS Selective Enr";
 summ templott if cu_hstst==1;
 tab dc if cu_hstst==1, miss;
 tab cunit year if dc=="" & cu_hstst==1;
 * no information to use to fill in for any missing dc codes-- other than
 fact that student attended the school;
 for num 1090 1740: tab dc insch if cunit==X & year==2000, miss row;
 for num 1440: tab dc insch if cunit==X & year==2001, miss row;

**Regular Magnets;

 tab cunit if (cutype=="Magnet"|cutype=="Magnet/Career Acad") & cunit<2000;
 gen byte cu_hsmag=(cunit==1790|cunit==1820|cunit==1610) if igradeS0>=8;
  label var cu_hsmag "App Sch = HS, Magnet";
 summ templott if cu_hsmag==1;
 tab dc if templott==0 & cu_hsmag==1, miss;
 * almost no dc codes are missing;
 tab dc if cu_hsmag==1, miss;
 for any S R 6 1 3: summ insch if cu_hsmag==1 & dc=="X";

**Other High Schools;

 gen temp=cu_hsvoc+cu_hstst+cu_hsmag;
 tab cutype if temp==0, miss;
 * including Hope with other schools;
 tab cunit if cutype=="College Prep" & temp==0;
 * include Carver with other schools;
 tab cunit if cutype=="Military Academy" & temp==0;
 tab cunit cuname if cutype=="Magnet" & temp==0;
 gen byte cu_hsoth=(temp==0) if temp~=.;
  label var cu_hsoth "App Sch = HS, General School";
 tab dc if cu_hsoth==1, miss;
 summ templott if cu_hsoth==1;
 tab cunit year if cu_hsoth==1 & dc=="";
 for num 1210 1240 1270 1310 1490 1530 1540 1560 1570 1620 1680 1860 1880:
   tab dc insch if cunit==X & year==2000, miss row;
 for num 1430 1620 1650 1670 1890 4130: 
   tab dc insch if cunit==X & year==2001, miss row;
 * filling in missing dc codes when can;
 for num 1210 1490 1530 1540 1570 1620: 
  replace dc="R^" if dc=="" & cunit==X & year==2000;
 for num 1620 1890: replace dc="R^" if dc=="" & cunit==X & year==2001;
 tab dc if cu_hsoth==1, miss;
 summ insch if cu_hsoth==1 & (dc=="A"|dc=="S"|dc=="P");
 summ insch if cu_hsoth==1 & (dc=="R"|dc=="R^"|dc=="3"|dc=="6");
 summ insch if cu_hsoth==1 & dc=="";
 
**Check coverage of categories;
 replace temp=temp+cu_hsoth;
 tab temp if igradeS0>=8, miss;
 drop temp*;
 count if igradeS0>=8;
 summ cu_hs*;

/** Create Classification Categories for FALL ENROLLMENT High Schools **/

 tab uF1type if gradeS0>=8;

**Career Academies;
 gen byte f_hsvoc=uF1type=="Career Academy" if unitF1~=.;
  label var f_hsvoc "Fall Sch = HS, Career Academy";
 tab unitF1 if f_hsvoc==1;
 replace f_hsvoc=0 if unitF1==1820;

**Selective Enrollment High Schools;
 gen byte f_hstst=0 if unitF1~=.;
 for num 1060 1440 1450 1740 1500 1090 1810: replace f_hstst=1 if 
   unitF1==X;
  label var f_hstst "Fall Sch = HS selective enr";

**Regular Magnets;
 tab uF1name if (uF1type=="Magnet"|uF1type=="Magnet/Career Acad") &
  (unitF1<2000);
 gen byte f_hsmag=0 if unitF1~=.;
 for num 1790 1820 1610: replace f_hsmag=1 if unitF1==X;
  label var f_hsmag "Fall Sch = HS, Magnet";

**Charter School;
 gen byte f_hschrt=uF1type=="Charter" if unitF1~=.;
 label var f_hschrt "Fall Sch = HS, Charter";

**Other High Schools;
 gen temp=f_hsvoc+f_hstst+f_hsmag+f_hschrt;
 tab uF1type if temp==0 & igradeS0>=8;
 tab uF1name if uF1type=="College Prep" & temp==0 & igradeS0>=8;
 tab uF1name if uF1type=="Magnet" & temp==0 & igradeS0>=8;
 gen byte f_hsoth=(temp==0) if igradeS0>=8 & unitF1~=.;
  label var f_hsoth "Fall Sch = HS, other school type";
  
**Set all of these variables to missing for elementary students;
 for any f_hsvoc f_hstst f_hsmag f_hschrt f_hsoth: replace X=.
  if igradeS0<8;
 
** Check coverage of categories;
 replace temp=f_hsvoc+f_hstst+f_hsmag+f_hschrt+f_hsoth;
 tab temp if unitF1~=. & enrollF1==1 & igradeS0>=8, miss;
 count if enrollF1==1 & igradeS0>=8;
 summ f_hs*;
 drop temp;
 
  compress;
  doub2flt _all;

order individ newid sid year badmatch baddemog napp*
 pc dc lotto sublotto p comments sx rc gr sb ngradeap igradeS0
 enrollS0 gradeS0 ngradeS0 latS0 longS0 tractS0* pri_* 
 rdgeS0 rdxilS0 mtxilS0 rdxil_1 mtxil_1 yy* xx* nn*
 unitS0 uS0name uS0type uS0p* uS0itbs uS0mnotaa
 cunit cuname cutype 
 cu_clas cu_mag* cu_el* cu_acad cu_rgif cu_ibprep cu_hs*
 cupwhi cupblk cuphis cuplep cuploinc cupattnd cupdrop cupgrad cusize 
 cupnorms cumnotaa cucrim cumedy cupov cumiles cutract
 cuppe cupsped cupar cuptr cuuniv1 cuunivmeas cumstpls cuscrths 
 cuscrtsub cutcrt cueducmjr
 insch dinsch enrollF1 dropF1 privF1 leftF1 gradeF1 ngradeF1 tractF1
 unitF1 uF1name uF1type f_el* f_hs*
 uF1pwhi uF1pblk uF1phis uF1plep uF1ploinc uF1pattnd uF1pdrop uF1pgrad uF1size
 uF1pnorms uF1mnotaa uF1crim uF1medy uF1pov uF1miles* uF1tract
 uF1ppe uF1psped uF1par uF1ptr uF1univ1 uF1univmeas uF1mstpls uF1scrths 
 uF1scrtsub uF1tcrt uF1educmjr
 enrollS1 gradeS1 unitS1 aunitS1 aaS1 aS1* rdgeS1 rdxilS1 mtxilS1 dropS1 
 leftS1 privS1
 biompS1 biocpS1 biotpS1 wldmpS1 wldcpS1 wldtpS1 algmpS1 algcpS1 algtpS1
 eng1mpS1 eng1cpS1 eng1tpS1 
 gpaS1 mabsS1 tcrdS1 anyfS1 numfS1 crankS1
 enrollS2 gradeS2 unitS2 aaS2 rdgeS2 rdxilS2 mtxilS2 dropS2 leftS2 privS2
 hismpS2 hiscpS2 histpS2 geompS2 geocpS2 geotpS2 eng2mpS2 eng2cpS2 eng2tpS2
 gpaS2 mabsS2 tcrdS2 anyfS2 numfS2 crankS2
 enrollS3 gradeS3 unitS3 dropS3 leftS3 privS3 dieS3 pregS3 jailS3 lvreaS3 lvexpS3
 enrollS4 gradeS4 unitS4 dropS4 leftS4 privS4
 enrollF5 gradeF5 dropF5 leftF5 privF5 gradF5 dieF5 pregF5 jailF5 lvreaF5 lvexpF5;

  desc;
  sum;

  save magbasevalid.dta, replace;
  log close;
